
# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

from django.conf.urls import patterns, url
from .views import IndexView, PresentPoolsView
from .views import PoolsAction,get_select_data,get_openstack_region_select_data,get_select_data2

urlpatterns = patterns('',
    url(r'^$', IndexView.as_view(), name='index'),
    url(r'^presentpools/$', PresentPoolsView.as_view(), name='presentpoolsview'),
    url(r'^pools/(?P<action>\w+)$', PoolsAction, name='poolsaction'),
    url(r'^get_select_data/$', get_select_data, name='get_select_data'),
    url(r'^get_select_data2/$', get_select_data2, name='get_select_data2'),
    url(r'^get_openstack_region_select_data/$', get_openstack_region_select_data, name='get_openstack_region_select_data'),
    #url(r'^create/$', CreateView.as_view(), name='create'),
    )





# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

import os

from django.utils.translation import ugettext_lazy as _

from vsm_dashboard import exceptions

DEBUG = False
TEMPLATE_DEBUG = DEBUG

# Set SSL proxy settings:
# For Django 1.4+ pass this header from the proxy after terminating the SSL,
# and don't forget to strip it from the client's request.
# For more information see:
# https://docs.djangoproject.com/en/1.4/ref/settings/#secure-proxy-ssl-header
# SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTOCOL', 'https')

# If Horizon is being served through SSL, then uncomment the following two
# settings to better secure the cookies from security exploits
#CSRF_COOKIE_SECURE = True
#SESSION_COOKIE_SECURE = True

# Default VSM Dashboard configuration.
HORIZON_CONFIG = {
    'dashboards': ('vsm',),
    'default_dashboard': 'vsm',
    'user_home': None,
    'ajax_queue_limit': 10,
    'auto_fade_alerts': {
        'delay': 3000,
        'fade_duration': 1500,
        'types': ['alert-success', 'alert-info']
    },
    'help_url': "dashboard/vsm",
    'exceptions': {'recoverable': exceptions.RECOVERABLE,
                   'not_found': exceptions.NOT_FOUND,
                   'unauthorized': exceptions.UNAUTHORIZED},
}

# Specify a regular expression to validate user passwords.
# HORIZON_CONFIG["password_validator"] = {
#     "regex": '.*',
#     "help_text": _("Your password does not meet the requirements.")
# }

# Disable simplified floating IP address management for deployments with
# multiple floating IP pools or complex network requirements.
# HORIZON_CONFIG["simple_ip_management"] = False

# Turn off browser autocompletion for the login form if so desired.
# HORIZON_CONFIG["password_autocomplete"] = "off"

LOCAL_PATH = os.path.dirname(os.path.abspath(__file__))
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': 'dashboard',
        'USER': 'dashboard',
        'PASSWORD': '88d549634a9cf1925fc8',
        'HOST': '10.239.82.234',
        'default-character-set': 'utf8'
    },
}

# Set custom secret key:
# You can either set it to a specific value or you can let horizion generate a
# default secret key that is unique on this machine, e.i. regardless of the
# amount of Python WSGI workers (if used behind Apache+mod_wsgi): However, there
# may be situations where you would want to set this explicitly, e.g. when
# multiple dashboard instances are distributed on different machines (usually
# behind a load-balancer). Either you have to make sure that a session gets all
# requests routed to the same dashboard instance or you set the same SECRET_KEY
# for all of them.
# from horizon.utils import secret_key
# SECRET_KEY = secret_key.generate_or_read_from_file(os.path.join(LOCAL_PATH, '.secret_key_store'))

# We recommend you use memcached for development; otherwise after every reload
# of the django development server, you will have to login again. To use
# memcached set CACHES to something like
# CACHES = {
#    'default': {
#        'BACKEND' : 'django.core.cache.backends.memcached.MemcachedCache',
#        'LOCATION' : '127.0.0.1:11211',
#    }
#}

CACHES = {
    'default': {
        'BACKEND' : 'django.core.cache.backends.locmem.LocMemCache'
    }
}

# Send email to the console by default
EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'
# Or send them to /dev/null
#EMAIL_BACKEND = 'django.core.mail.backends.dummy.EmailBackend'

# Configure these for your outgoing email host
# EMAIL_HOST = 'smtp.my-company.com'
# EMAIL_PORT = 25
# EMAIL_HOST_USER = 'djangomail'
# EMAIL_HOST_PASSWORD = 'top-secret!'

# For multiple regions uncomment this configuration, and add (endpoint, title).
# AVAILABLE_REGIONS = [
#     ('http://cluster1.example.com:5000/v2.0', 'cluster1'),
#     ('http://cluster2.example.com:5000/v2.0', 'cluster2'),
# ]

KEYSTONE_VSM_SERVICE_PASSWORD = "056e122005e0ad5c8bb1"
OPENSTACK_HOST = "10.239.82.234"
OPENSTACK_KEYSTONE_URL = "http://%s:5000/v2.0" % OPENSTACK_HOST
OPENSTACK_KEYSTONE_DEFAULT_ROLE = "Member"

# Disable SSL certificate checks (useful for self-signed certificates):
# OPENSTACK_SSL_NO_VERIFY = True

# The OPENSTACK_KEYSTONE_BACKEND settings can be used to identify the
# capabilities of the auth backend for Keystone.
# If Keystone has been configured to use LDAP as the auth backend then set
# can_edit_user to False and name to 'ldap'.
#
# TODO(tres): Remove these once Keystone has an API to identify auth backend.
OPENSTACK_KEYSTONE_BACKEND = {
    'name': 'native',
    'can_edit_user': True,
    'can_edit_project': True
}

OPENSTACK_HYPERVISOR_FEATURES = {
    'can_set_mount_point': False,

    # NOTE: as of Grizzly this is not yet supported in Nova so enabling this
    # setting will not do anything useful
    'can_encrypt_volumes': False
}

# The OPENSTACK_QUANTUM_NETWORK settings can be used to enable optional
# services provided by quantum.  Currently only the load balancer service
# is available.
OPENSTACK_QUANTUM_NETWORK = {
    'enable_lb': False
}

# OPENSTACK_ENDPOINT_TYPE specifies the endpoint type to use for the endpoints
# in the Keystone service catalog. Use this setting when Horizon is running
# external to the VSM environment. The default is 'internalURL'.
#OPENSTACK_ENDPOINT_TYPE = "publicURL"

# The number of objects (Swift containers/objects or images) to display
# on a single page before providing a paging element (a "more" link)
# to paginate results.
API_RESULT_LIMIT = 1000
API_RESULT_PAGE_SIZE = 20

# The timezone of the server. This should correspond with the timezone
# of your entire VSM installation, and hopefully be in UTC.
TIME_ZONE = "UTC"

LOGGING = {
    'version': 1,
    # When set to True this will disable all logging except
    # for loggers specified in this configuration dictionary. Note that
    # if nothing is specified here and disable_existing_loggers is True,
    # django.db.backends will still log unless it is disabled explicitly.
    'disable_existing_loggers': False,
    'handlers': {
        'null': {
            'level': 'DEBUG',
            'class': 'django.utils.log.NullHandler',
        },
        'console': {
            # Set the level to "DEBUG" for verbose output logging.
            'level': 'INFO',
            'class': 'logging.StreamHandler',
        },
    },
    'loggers': {
        # Logging from django.db.backends is VERY verbose, send to null
        # by default.
        'django.db.backends': {
            'handlers': ['null'],
            'propagate': False,
        },
        'requests': {
            'handlers': ['null'],
            'propagate': False,
        },
        'horizon': {
            'handlers': ['console'],
            'propagate': False,
        },
        'vsm_dashboard': {
            'handlers': ['console'],
            'propagate': False,
        },
        'keystoneclient': {
            'handlers': ['console'],
            'propagate': False,
        },
        'nose.plugins.manager': {
            'handlers': ['console'],
            'propagate': False,
        }
    }
}



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import logging
import json

from django.http import HttpResponse
from django.views.generic import TemplateView
from django.core.urlresolvers import reverse, reverse_lazy
from horizon import forms
from vsm_dashboard.api import vsm as vsmapi
from .forms import CreateConfigurationForm
from .forms import UpdateConfigurationForm

LOG = logging.getLogger(__name__)

class IndexView(TemplateView):
    template_name = 'vsm/configuration/index.html'
    def get_context_data(self, **kwargs):
        context = super(IndexView, self).get_context_data(**kwargs)
        ceph_config = [
            {"section": "global", "items": [
                {"id": 1, "name": "name1", "value": "1", "default_value": "1", "category": "CEPH", "alterable": True, "description": "name1"},
                {"id": 2, "name": "name2", "value": "1", "default_value": "1", "category": "CEPH", "alterable": True, "description": "name2"},
                {"id": 3, "name": "name3", "value": "1", "default_value": "1", "category": "CEPH", "alterable": True, "description": "name3"}
            ]},
            {"section": "mon", "items": [
                {"id": 4, "name": "name4", "value": "1", "default_value": "1", "category": "CEPH", "alterable": True, "description": "name4"},
                {"id": 5, "name": "name5", "value": "1", "default_value": "1", "category": "CEPH", "alterable": True, "description": "name5"},
                {"id": 6, "name": "name6", "value": "1", "default_value": "1", "category": "CEPH", "alterable": True, "description": "name6"},
                {"id": 7, "name": "name7", "value": "1", "default_value": "1", "category": "CEPH", "alterable": True, "description": "name7"}
            ]},
            {"section": "osd", "items": [
                {"id": 8, "name": "name8", "value": "1", "default_value": "1", "category": "CEPH", "alterable": True, "description": "name8"},
                {"id": 9, "name": "name9", "value": "1", "default_value": "1", "category": "CEPH", "alterable": True, "description": "name9"}
            ]},
            {"section": "mds", "items": [
                {"id": 10, "name": "name10", "value": "1", "default_value": "1", "category": "CEPH", "alterable": True, "description": "name10"},
                {"id": 11, "name": "name11", "value": "1", "default_value": "1", "category": "CEPH", "alterable": True, "description": "name11"}
            ]}
        ]
        context["config_list"] = ceph_config
        return context;


class CreateView(forms.ModalFormView):
    form_class = CreateConfigurationForm
    template_name = 'vsm/configuration/create.html'
    success_url = reverse_lazy('horizon:vsm:configuration:index')

class UpdateView(forms.ModalFormView):
    form_class = UpdateConfigurationForm
    template_name = 'vsm/configuration/update.html'
    success_url = reverse_lazy('horizon:vsm:configuration:index')

    def get_context_data(self, **kwargs):
        context = super(UpdateView, self).get_context_data(**kwargs)
        context['config_id'] = self.kwargs['config_id']
        return context

    def get_initial(self):
        #TODO: you can use this argument to get the configuration entity to update.
        config_id = self.kwargs['config_id']
        return {'name': "12345",
                'section': "mon",
                'default_value': "hahaha",
                'current_value': "hehehehe"}


def create(request):
    data = json.loads(request.body)
    print "============create the configuration============="
    print data
    try:
        #TODO: create the configuration
        resp = dict(message="Create configuration successfully", status="OK", data="")
        resp = json.dumps(resp)
        return HttpResponse(resp)
    except:
        resp = dict(message="Create configuration failed", status="Failed", data="")
        resp = json.dumps(resp)
        return HttpResponse(resp)


def update(request):
    data = json.loads(request.body)
    print "============update the configuration============="
    print data
    try:
        #TODO: create the configuration
        resp = dict(message="Update configuration successfully", status="OK", data="")
        resp = json.dumps(resp)
        return HttpResponse(resp)
    except:
        resp = dict(message="Update configuration failed", status="Failed", data="")
        resp = json.dumps(resp)
        return HttpResponse(resp)


def delete_action(request):
    data = json.loads(request.body)
    print "============delete the configuration============="
    print data
    try:
        #TODO: create the configuration
        resp = dict(message="Delete configuration successfully", status="OK", data="")
        resp = json.dumps(resp)
        return HttpResponse(resp)
    except:
        resp = dict(message="Delete configuration failed", status="Failed", data="")
        resp = json.dumps(resp)
        return HttpResponse(resp)






# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

from django import template
from django.views.generic import View
import logging
LOG = logging.getLogger(__name__)

class TextRenderer(View):
    def __init__(self, request):
        self.request = request

    def render(self):
        text_template = template.loader.get_template("vsm/text.html")

        try:
            data = self.get_text()
        except Exception,e:
            data = {}
            LOG.error("CRITICAL:%s "%e)
            #LOG.error(e)

        context = template.Context({
                                    "name": self.name, 
                                    "text": data,
                                   })
        LOG.debug("Text render context:%s " % context)
        return text_template.render(context)



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2012 NEC Corporation
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from vsm_dashboard import api
from vsm_dashboard.test import helpers as test

class QuantumApiTests(test.APITestCase):
    def test_network_list(self):
        networks = {'networks': self.api_networks.list()}
        subnets = {'subnets': self.api_subnets.list()}

        quantumclient = self.stub_quantumclient()
        quantumclient.list_networks().AndReturn(networks)
        quantumclient.list_subnets().AndReturn(subnets)
        self.mox.ReplayAll()

        ret_val = api.quantum.network_list(self.request)
        for n in ret_val:
            self.assertIsInstance(n, api.quantum.Network)

    def test_network_get(self):
        network = {'network': self.api_networks.first()}
        subnet = {'subnet': self.api_subnets.first()}
        network_id = self.api_networks.first()['id']
        subnet_id = self.api_networks.first()['subnets'][0]

        quantumclient = self.stub_quantumclient()
        quantumclient.show_network(network_id).AndReturn(network)
        quantumclient.show_subnet(subnet_id).AndReturn(subnet)
        self.mox.ReplayAll()

        ret_val = api.quantum.network_get(self.request, network_id)
        self.assertIsInstance(ret_val, api.quantum.Network)

    def test_network_create(self):
        network = {'network': self.api_networks.first()}

        quantumclient = self.stub_quantumclient()
        form_data = {'network': {'name': 'net1'}}
        quantumclient.create_network(body=form_data).AndReturn(network)
        self.mox.ReplayAll()

        ret_val = api.quantum.network_create(self.request, name='net1')
        self.assertIsInstance(ret_val, api.quantum.Network)

    def test_network_modify(self):
        network = {'network': self.api_networks.first()}
        network_id = self.api_networks.first()['id']

        quantumclient = self.stub_quantumclient()
        form_data = {'network': {'name': 'net1'}}
        quantumclient.update_network(network_id, body=form_data)\
            .AndReturn(network)
        self.mox.ReplayAll()

        ret_val = api.quantum.network_modify(self.request, network_id,
                                             name='net1')
        self.assertIsInstance(ret_val, api.quantum.Network)

    def test_network_delete(self):
        network_id = self.api_networks.first()['id']

        quantumclient = self.stub_quantumclient()
        quantumclient.delete_network(network_id)
        self.mox.ReplayAll()

        api.quantum.network_delete(self.request, network_id)

    def test_subnet_list(self):
        subnets = {'subnets': self.api_subnets.list()}

        quantumclient = self.stub_quantumclient()
        quantumclient.list_subnets().AndReturn(subnets)
        self.mox.ReplayAll()

        ret_val = api.quantum.subnet_list(self.request)
        for n in ret_val:
            self.assertIsInstance(n, api.quantum.Subnet)

    def test_subnet_get(self):
        subnet = {'subnet': self.api_subnets.first()}
        subnet_id = self.api_subnets.first()['id']

        quantumclient = self.stub_quantumclient()
        quantumclient.show_subnet(subnet_id).AndReturn(subnet)
        self.mox.ReplayAll()

        ret_val = api.quantum.subnet_get(self.request, subnet_id)
        self.assertIsInstance(ret_val, api.quantum.Subnet)

    def test_subnet_create(self):
        subnet_data = self.api_subnets.first()
        params = {'network_id': subnet_data['network_id'],
                  'tenant_id': subnet_data['tenant_id'],
                  'name': subnet_data['name'],
                  'cidr': subnet_data['cidr'],
                  'ip_version': subnet_data['ip_version'],
                  'gateway_ip': subnet_data['gateway_ip']}

        quantumclient = self.stub_quantumclient()
        quantumclient.create_subnet(body={'subnet': params})\
            .AndReturn({'subnet': subnet_data})
        self.mox.ReplayAll()

        ret_val = api.quantum.subnet_create(self.request, **params)
        self.assertIsInstance(ret_val, api.quantum.Subnet)

    def test_subnet_modify(self):
        subnet_data = self.api_subnets.first()
        subnet_id = subnet_data['id']
        params = {'name': subnet_data['name'],
                  'gateway_ip': subnet_data['gateway_ip']}

        quantumclient = self.stub_quantumclient()
        quantumclient.update_subnet(subnet_id, body={'subnet': params})\
            .AndReturn({'subnet': subnet_data})
        self.mox.ReplayAll()

        ret_val = api.quantum.subnet_modify(self.request, subnet_id, **params)
        self.assertIsInstance(ret_val, api.quantum.Subnet)

    def test_subnet_delete(self):
        subnet_id = self.api_subnets.first()['id']

        quantumclient = self.stub_quantumclient()
        quantumclient.delete_subnet(subnet_id)
        self.mox.ReplayAll()

        api.quantum.subnet_delete(self.request, subnet_id)

    def test_port_list(self):
        ports = {'ports': self.api_ports.list()}

        quantumclient = self.stub_quantumclient()
        quantumclient.list_ports().AndReturn(ports)
        self.mox.ReplayAll()

        ret_val = api.quantum.port_list(self.request)
        for p in ret_val:
            self.assertIsInstance(p, api.quantum.Port)

    def test_port_get(self):
        port = {'port': self.api_ports.first()}
        port_id = self.api_ports.first()['id']

        quantumclient = self.stub_quantumclient()
        quantumclient.show_port(port_id).AndReturn(port)
        self.mox.ReplayAll()

        ret_val = api.quantum.port_get(self.request, port_id)
        self.assertIsInstance(ret_val, api.quantum.Port)

    def test_port_create(self):
        port_data = self.api_ports.first()
        params = {'network_id': port_data['network_id'],
                  'tenant_id': port_data['tenant_id'],
                  'name': port_data['name'],
                  'device_id': port_data['device_id']}

        quantumclient = self.stub_quantumclient()
        quantumclient.create_port(body={'port': params})\
            .AndReturn({'port': port_data})
        self.mox.ReplayAll()

        ret_val = api.quantum.port_create(self.request, **params)
        self.assertIsInstance(ret_val, api.quantum.Port)
        self.assertEqual(ret_val.id, api.quantum.Port(port_data).id)

    def test_port_modify(self):
        port_data = self.api_ports.first()
        port_id = port_data['id']
        params = {'name': port_data['name'],
                  'device_id': port_data['device_id']}

        quantumclient = self.stub_quantumclient()
        quantumclient.update_port(port_id, body={'port': params})\
            .AndReturn({'port': port_data})
        self.mox.ReplayAll()

        ret_val = api.quantum.port_modify(self.request, port_id, **params)
        self.assertIsInstance(ret_val, api.quantum.Port)
        self.assertEqual(ret_val.id, api.quantum.Port(port_data).id)

    def test_port_delete(self):
        port_id = self.api_ports.first()['id']

        quantumclient = self.stub_quantumclient()
        quantumclient.delete_port(port_id)
        self.mox.ReplayAll()

        api.quantum.port_delete(self.request, port_id)

    def test_router_list(self):
        routers = {'routers': self.api_routers.list()}

        quantumclient = self.stub_quantumclient()
        quantumclient.list_routers().AndReturn(routers)
        self.mox.ReplayAll()

        ret_val = api.quantum.router_list(self.request)
        for n in ret_val:
            self.assertIsInstance(n, api.quantum.Router)

    def test_router_get(self):
        router = {'router': self.api_routers.first()}
        router_id = self.api_routers.first()['id']

        quantumclient = self.stub_quantumclient()
        quantumclient.show_router(router_id).AndReturn(router)
        self.mox.ReplayAll()

        ret_val = api.quantum.router_get(self.request, router_id)
        self.assertIsInstance(ret_val, api.quantum.Router)

    def test_router_create(self):
        router = {'router': self.api_routers.first()}

        quantumclient = self.stub_quantumclient()
        form_data = {'router': {'name': 'router1'}}
        quantumclient.create_router(body=form_data).AndReturn(router)
        self.mox.ReplayAll()

        ret_val = api.quantum.router_create(self.request, name='router1')
        self.assertIsInstance(ret_val, api.quantum.Router)

    def test_router_delete(self):
        router_id = self.api_routers.first()['id']

        quantumclient = self.stub_quantumclient()
        quantumclient.delete_router(router_id)
        self.mox.ReplayAll()

        api.quantum.router_delete(self.request, router_id)

    def test_router_add_interface(self):
        subnet_id = self.api_subnets.first()['id']
        router_id = self.api_routers.first()['id']

        quantumclient = self.stub_quantumclient()
        form_data = {'subnet_id': subnet_id}
        quantumclient.add_interface_router(
            router_id, form_data).AndReturn(None)
        self.mox.ReplayAll()

        api.quantum.router_add_interface(
            self.request, router_id, subnet_id=subnet_id)

    def test_router_remove_interface(self):
        router_id = self.api_routers.first()['id']
        fake_port = self.api_ports.first()['id']

        quantumclient = self.stub_quantumclient()
        quantumclient.remove_interface_router(
            router_id, {'port_id': fake_port})
        self.mox.ReplayAll()

        api.quantum.router_remove_interface(
            self.request, router_id, port_id=fake_port)




# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

from django.utils.translation import ugettext as _

from horizon import exceptions
from horizon import tabs

from vsm_dashboard.dashboards.vsm.flocking import utils
from .tables import FlockingInstancesTable
from .tables import ListRecipeTable

class DataTab(tabs.TableTab):
    name = _("Data")
    slug = "data"
    table_classes = (ListRecipeTable,)
    template_name = "horizon/common/_detail_table.html"
    preload = False

    def get_instances_data(self):
        try:
            instances = utils.get_instances_data(self.tab_group.request)
        except:
            instances = []
            exceptions.handle(self.tab_group.request,
                              _('Unable to retrieve instance list.'))
        return instances

    def get_recipe_data(self):
        try:
            #instances = "kidding you"
            instances = utils.get_instances_data(self.tab_group.request)
        except:
            instances = []
            exceptions.handle(self.tab_group.request,
                              _('Unable to retrieve instance list.'))
        return instances

class VizTab(tabs.Tab):
    name = _("Capacity")
    slug = "viz"
    template_name = "vsm/flocking/_flocking.html"

    def get_context_data(self, request):
        return None

class FlockingTabs(tabs.TabGroup):
    slug = "recipe"
    #tabs = (VizTab, DataTab)
    tabs = (DataTab,)



# Copyright 2012 Nebula, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

def load_test_data(load_onto=None):
    from . import exceptions
    from . import glance_data
    from . import keystone_data
    from . import nova_data
    from . import quantum_data
    from . import swift_data

    # The order of these loaders matters, some depend on others.
    loaders = (exceptions.data,
               keystone_data.data,
               glance_data.data,
               nova_data.data,
               quantum_data.data,
               swift_data.data)
    if load_onto:
        for data_func in loaders:
            data_func(load_onto)
        return load_onto
    else:
        return TestData(*loaders)

class TestData(object):
    """
    Holder object for test data. Any functions passed to the init method
    will be called with the ``TestData`` object as their only argument. They
    can then load data onto the object as desired.

    The idea is to use the instantiated object like this::

        >>> import glance_data
        >>> TEST = TestData(glance_data.data)
        >>> TEST.images.list()
        ... [<Image: visible_image>, <Image: invisible_image>]
        >>> TEST.images.first()
        ... <Image: visible_image>

    You can load as little or as much data as you like as long as the loaders
    don't conflict with each other.

    See the :class:`~horizon.tests.test_data.utils.TestDataContainer` class
    for a list of available methods.
    """
    def __init__(self, *args):
        for data_func in args:
            data_func(self)

class TestDataContainer(object):
    """ A container for test data objects.

    The behavior of this class is meant to mimic a "manager" class, which
    has convenient shortcuts for common actions like "list", "filter", "get",
    and "add".
    """
    def __init__(self):
        self._objects = []

    def add(self, *args):
        """ Add a new object to this container.

        Generally this method should only be used during data loading, since
        adding data during a test can affect the results of other tests.
        """
        for obj in args:
            if obj not in self._objects:
                self._objects.append(obj)

    def list(self):
        """ Returns a list of all objects in this container. """
        return self._objects

    def filter(self, filtered=None, **kwargs):
        """
        Returns objects in this container whose attributes match the given
        keyword arguments.
        """
        if filtered is None:
            filtered = self._objects
        try:
            key, value = kwargs.popitem()
        except KeyError:
            # We're out of filters, return
            return filtered

        def get_match(obj):
            return hasattr(obj, key) and getattr(obj, key) == value

        return self.filter(filtered=filter(get_match, filtered), **kwargs)

    def get(self, **kwargs):
        """
        Returns the single object in this container whose attributes match
        the given keyword arguments. An error will be raised if the arguments
        provided don't return exactly one match.
        """
        matches = self.filter(**kwargs)
        if not matches:
            raise Exception("No matches found.")
        elif len(matches) > 1:
            raise Exception("Multiple matches found.")
        else:
            return matches.pop()

    def first(self):
        """ Returns the first object from this container. """
        return self._objects[0]

    def count(self):
        return len(self._objects)



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
from django.core.validators import RegexValidator
import re
from django.utils.translation import ugettext_lazy as _
from django.core.validators import BaseValidator
from django.core.exceptions import ValidationError


_user_name_re = re.compile("^[A-Za-z0-9\@\.\_]+$")
validate_user_name = RegexValidator(_user_name_re, _("Enter a valid User name! "), "invalid")

password_validate_regrex = "^(?=.*[a-z].*)(?=.*[A-Z].*)(?=.*[0-9].*)(?=.*[@#$%^&*\.:;~\\\|\[\]\{\}].*).{8,255}$"

_zone_name_re = re.compile("^[A-Za-z0-9\.\_]+$")
validate_zone_name = RegexValidator(_zone_name_re, _("Enter a valid Zone name! "), "invalid")

_pool_name_re = re.compile("^[A-Za-z0-9\@\.\_]+$")
validate_pool_name = RegexValidator(_pool_name_re, _("Enter a valid Pool name! "), "invalid")

_storage_group_name_re = re.compile("^[A-Za-z0-9\.\_]+$")
validate_storage_group_name = RegexValidator(_storage_group_name_re, _("Enter a valid Zone name! "), "invalid")

class StorageGroupValidator(BaseValidator):
    storage_group = None
    def __init__(self, replicated=False):
        self.replicated = replicated

    def __call__(self, value):
        if not self.replicated:
            StorageGroupValidator.storage_group = value
            return True
        if StorageGroupValidator.storage_group == value:
            raise ValidationError("You should choose \"Default same as Primary\"", "invalid")
        return True



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import logging
import json
import os
import commands

from django.utils.translation import ugettext_lazy as _
from django.core.urlresolvers import reverse_lazy
from django.core.urlresolvers import reverse
from django.http import HttpResponse

from horizon import exceptions
from horizon import tables
from horizon import forms

from vsm_dashboard.api import vsm as vsmapi
from .tables import ListOpenstackEndpointTable
from .forms import AddOpenstackEndpointForm
from .forms import UpdateOpenstackEndpointForm

LOG = logging.getLogger(__name__)

class IndexView(tables.DataTableView):
    table_class = ListOpenstackEndpointTable
    template_name = 'vsm/openstackconnect/index.html'

    def get_data(self):
        _appnode_list = []
        try:
            _appnode_list = vsmapi.appnode_list(self.request)
        except:
            exceptions.handle(self.request,
                   _('Unable to retrieve openstack endpoint list. '))

        appnode_list = []
        for _appnode in _appnode_list:
            appnode = {
                "id": str(_appnode.id),
                "os_tenant_name": _appnode.os_tenant_name,
                "os_username": _appnode.os_username,
                "os_password": _appnode.os_password,
                "os_auth_url": _appnode.os_auth_url,
                "os_region_name": _appnode.os_region_name,
                "ssh_user": _appnode.ssh_user,
                "ssh_status": _appnode.ssh_status,
                "log_info": _appnode.log_info
            }
            appnode_list.append(appnode)

        return appnode_list

class CreateView(forms.ModalFormView):
    form_class = AddOpenstackEndpointForm
    template_name = 'vsm/openstackconnect/create.html'

class UpdateView(forms.ModalFormView):
    form_class = UpdateOpenstackEndpointForm
    template_name = 'vsm/openstackconnect/update.html'
    success_url = reverse_lazy('horizon:vsm:openstackconnect:index')

    def get_object(self):
        LOG.info("CEPH_LOG UPDATE VIEW:%s"%self.kwargs)
        if not hasattr(self, "_object"):
            try:
                appnodes = vsmapi.appnode_list(self.request)
                for appnode in appnodes:
                    if str(appnode.id) == self.kwargs['appnode_id']:
                        self._object = appnode

            except:
                redirect = reverse("horizon:vsm:openstackconnect:index")
                exceptions.handle(self.request,
                                  _('Unable to Edit OpenStack Access.'),
                                  redirect=redirect)
        return self._object

    def get_context_data(self, **kwargs):
        context = super(UpdateView, self).get_context_data(**kwargs)
        context['appnode'] = self.get_object()
        return context

    def get_initial(self):
        LOG.info("CEPH_LOG UPDATE VIEW GET INITIAL: %s" % self.kwargs)
        appnode = self.get_object()
        return {
            'id': appnode.id,
            'os_tenant_name': appnode.os_tenant_name,
            'os_username': appnode.os_username,
            'os_password': appnode.os_password,
            'os_auth_url': appnode.os_auth_url,
            'os_region_name': appnode.os_region_name,
            "ssh_user": appnode.ssh_user
        }

def create_action(request):
    data = json.loads(request.body)
    # TODO deliver a cluster id in data
    data['cluster_id'] = 1
    try:
        LOG.info("CEPH_LOG in ADD OpenStack Endpoint, %s" % str(data))
        os_tenant_name = data['os_tenant_name']
        os_username = data['os_username']
        os_password = data['os_password']
        os_auth_url = data['os_auth_url']
        os_region_name = data['os_region_name']
        ssh_user = data['ssh_user']

        body = {
            'appnodes': {
                'os_tenant_name': os_tenant_name,
                'os_username': os_username,
                'os_password': os_password,
                'os_auth_url': os_auth_url,
                'os_region_name': os_region_name,
                'ssh_user': ssh_user
            }
        }
        LOG.info("CEPH_LOG in handle body %s" % str(body))
        vsmapi.add_appnodes(request, body['appnodes'])
        status = "info"
        msg = "Create Openstack Access Successfully!"
    except:
        status = "error"
        msg = "Create Openstack Access Failed! Please check crudini command and mutual trust"

    resp = dict(message=msg, status=status)
    resp = json.dumps(resp)
    return HttpResponse(resp)


def update_action(request):
    data = json.loads(request.body)
    try:
        id = data.pop('id')
        os_tenant_name = data.pop('os_tenant_name')
        os_username = data.pop('os_username')
        os_password = data.pop('os_password')
        os_auth_url = data.pop('os_auth_url')
        os_region_name = data.pop('os_region_name')
        ssh_user = data.pop('ssh_user')
        vsmapi.update_appnode(
            request, id,
            os_tenant_name=os_tenant_name,
            os_username=os_username,
            os_password=os_password,
            os_auth_url=os_auth_url,
            os_region_name=os_region_name,
            ssh_user=ssh_user,
            ssh_status="",
            log_info=""
        )
        status = "OK"
        msg = "Update Openstack Access Successfully!"
    except:
        status = "Failed"
        msg = "Update Openstack Access Failed!"

    resp = dict(message=msg, status=status)
    resp = json.dumps(resp)
    return HttpResponse(resp)




# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

from django.core import urlresolvers
from django.utils.translation import ugettext_lazy as _
from django.template.defaultfilters import timesince, floatformat

from horizon import tables
from horizon.templatetags.sizeformat import mbformat

class CSVSummary(tables.LinkAction):
    name = "csv_summary"
    verbose_name = _("Download CSV Summary")
    classes = ("btn-download",)

    def get_link_url(self, usage=None):
        return self.table.kwargs['usage'].csv_link()

class BaseUsageTable(tables.DataTable):
    vcpus = tables.Column('vcpus', verbose_name=_("VCPUs"))
    disk = tables.Column('local_gb', verbose_name=_("Disk"))
    memory = tables.Column('memory_mb',
                           verbose_name=_("RAM"),
                           filters=(mbformat,),
                           attrs={"data-type": "size"})
    hours = tables.Column('vcpu_hours', verbose_name=_("VCPU Hours"),
                          filters=(lambda v: floatformat(v, 2),))

class GlobalUsageTable(BaseUsageTable):
    tenant = tables.Column('tenant_name', verbose_name=_("Project Name"))
    disk_hours = tables.Column('disk_gb_hours',
                               verbose_name=_("Disk GB Hours"),
                               filters=(lambda v: floatformat(v, 2),))

    def get_object_id(self, datum):
        return datum.tenant_id

    class Meta:
        name = "global_usage"
        verbose_name = _("Usage Summary")
        columns = ("tenant", "vcpus", "disk", "memory",
                   "hours", "disk_hours")
        table_actions = (CSVSummary,)
        multi_select = False

def get_instance_link(datum):
    view = "horizon:project:instances:detail"
    if datum.get('instance_id', False):
        return urlresolvers.reverse(view, args=(datum.get('instance_id'),))
    else:
        return None

class TenantUsageTable(BaseUsageTable):
    instance = tables.Column('name',
                             verbose_name=_("Instance Name"),
                             link=get_instance_link)
    uptime = tables.Column('uptime_at',
                           verbose_name=_("Uptime"),
                           filters=(timesince,))

    def get_object_id(self, datum):
        return datum.get('instance_id', id(datum))

    class Meta:
        name = "tenant_usage"
        verbose_name = _("Usage Summary")
        columns = ("instance", "vcpus", "disk", "memory", "uptime")
        table_actions = (CSVSummary,)
        multi_select = False




# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

from django.template.defaultfilters import filesizeformat
from django.utils.translation import ugettext_lazy as _

#from vsm_dashboard.dashboards.admin.instances.tables import \
#        AdminUpdateRow

from horizon import tables
from vsm_dashboard.api import vsm

def get_tenant_name(instance):
    return instance.tenant.name

def get_memory(instance):
    return filesizeformat(instance.flavor.ram * 1024 * 1024)

def get_vcpus(instance):
    return instance.flavor.vcpus

def get_username(instance):
    return instance.user.name

def get_crushset():
    res = {}
    res['crush_ruleset'] = 'test data'
    return "test data"

class UpdateRow(tables.Row):
    ajax = True

    def get_data(self, request, volume_id):
        volume = vsm.volume_get(request, volume_id)
        if not volume.display_name:
            volume.display_name = volume_id
        return volume

class FlockingInstancesTable(tables.DataTable):
    host = tables.Column("OS-EXT-SRV-ATTR:host", verbose_name=_("Host"))
    tenant = tables.Column(get_tenant_name, verbose_name=_("Tenant"))
    user = tables.Column(get_username, verbose_name=_("user"))
    vcpus = tables.Column(get_vcpus, verbose_name=_("VCPUs"))
    memory = tables.Column(get_memory, verbose_name=_("Memory"))
    #age = tables.Column('age', verbose_name=_("Age"), filters=(timesince,))

    class Meta:
        name = "instances"
        verbose_name = _("Instances")
        #row_class = AdminUpdateRow

class CreateStoragePool(tables.LinkAction):
    name = "create pool"
    verbose_name = _("Create Pool")
    url = "horizon:project:volumes:create"
    classes = ("ajax-modal", "btn-create")

class DeleteStoragePool(tables.DeleteAction):
    data_type_singular = _("StoragePool")
    data_type_plural = _("StoragePools")
    action_past = _("Scheduled deletion of")

    def delete(self, request, obj_id):
        obj = self.table.get_object_by_id(obj_id)
        name = self.table.get_object_display(obj)
        try:
            vsm.volume_delete(request, obj_id)
        except:
            msg = _('Unable to delete volume "%s". One or more snapshots '
                    'depend on it.')
            exceptions.check_message(["snapshots", "dependent"], msg % name)
            raise

    def allowed(self, request, volume=None):
        if volume:
            return volume.status in DELETABLE_STATES
        return True

class ListRecipeTable(tables.DataTable):
    host = tables.Column(get_crushset, verbose_name=_("Name"))
    tenant = tables.Column(get_crushset, verbose_name=_("ID"))
    user = tables.Column(get_crushset, verbose_name=_("UpdateTime"))
    vcpus = tables.Column(get_crushset, verbose_name=_("Pg_number"))
    memory = tables.Column(get_crushset, verbose_name=_("crush_ruleset"))
    #age = tables.Column('age', verbose_name=_("Age"), filters=(timesince,))

    class Meta:
        name = "recipe"
        verbose_name = _("recipe")
        #row_class = AdminUpdateRow
        #row_class = UpdateRow
        table_actions = (CreateStoragePool, DeleteStoragePool,)
        row_actions = (DeleteStoragePool,)



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import logging
from django.utils.translation import ugettext_lazy as _
from django import forms
from django.conf import settings
from horizon import tables
from horizon import exceptions

from vsm_dashboard.api import vsm as vsmapi
STRING_SEPARATOR = "__"
LOG = logging.getLogger(__name__)

class UpdateRow(tables.Row):
    ajax = True

    def get_data(self, request, id):
        # todo update zone info in apiclient CEPH_LOG
        try:
            _zones = vsmapi.get_zone_list(request,)
        except:
            exceptions.handle(request,
                              _('Unable to retrieve sever list. '))
        zones = {}
        for _zone in _zones:
            zones.setdefault(_zone.id, _zone.name)

        _server = vsmapi.get_server(request, id)
        server = {"id": _server.id,
                  "name": _server.host,
                  "primary_public_ip": _server.primary_public_ip,
                  "secondary_public_ip": _server.secondary_public_ip,
                  "cluster_ip": _server.cluster_ip,
                  "zone_id": _server.zone_id,
                  "ceph_ver": _server.ceph_ver,
                  "zone": "",
                  "osds": _server.osds,
                  "type": _server.type,
                  "status": _server.status}
        if "monitor" in _server.type:
                server['is_monitor'] = "yes"
        else:
                server['is_monitor'] = "no"
        if _server.zone_id in zones:
            server['zone'] = zones[_server.zone_id]

        return server

STATUS_DISPLAY_CHOICES = (
    ("resize", "Resize/Migrate"),
    ("verify_resize", "Confirm or Revert Resize/Migrate"),
    ("revert_resize", "Revert Resize/Migrate"),
)

class ResetStatus(tables.BatchAction):
    name = "reset"
    action_present = _("Reset")
    action_past = _("Status Rested")
    data_type_singular = _("Server Status")
    data_type_plural = _("Servers Status")
    classes = ("reset-status-action", "")

    def allowed(self, request, instance=None):
        return (instance["status"] in ("running", "stopping", "removing", "adding", "starting")) or ("ERROR" in instance["status"])

    def action(self, request, obj_id):
        LOG.info("RESET_STATUS")
        vsmapi.reset_status(request, [obj_id])

class AddServersAction(tables.LinkAction):
    name = "add_servers"
    verbose_name = _("Add Servers")
    url = "horizon:vsm:storageservermgmt:addserversview"
    classes = ("ajax-modal", "btn-primary")

class RemoveServersAction(tables.LinkAction):
    name = "remove_servers"
    verbose_name = _("Remove Servers")
    url = "horizon:vsm:storageservermgmt:removeserversview"
    classes = ("ajax-modal", "btn-primary")

class AddMonitorsAction(tables.LinkAction):
    name = "add_monitors"
    verbose_name = _("Add Monitors")
    url = "horizon:vsm:storageservermgmt:addmonitorsview"
    classes = ("ajax-modal", "btn-primary")

class RemoveMonitorsAction(tables.LinkAction):
    name = "remove_monitors"
    verbose_name = _("Remove Monitors")
    url = "horizon:vsm:storageservermgmt:removemonitorsview"
    classes = ("ajax-modal", "btn-primary")

class StartServersAction(tables.LinkAction):
    name = "start_servers"
    verbose_name = _("Start Servers")
    url = "horizon:vsm:storageservermgmt:startserversview"
    classes = ("ajax-modal", "btn-primary")

class StopServersAction(tables.LinkAction):
    name = "stop_servers"
    verbose_name = _("Stop Servers")
    url = "horizon:vsm:storageservermgmt:stopserversview"
    classes = ("ajax-modal", "btn-primary")

class CephUpgradeAction(tables.LinkAction):
    name = "ceph_upgrade"
    verbose_name = _("Ceph Upgrade")
    url = "horizon:vsm:storageservermgmt:cephupgradeview"
    classes = ("ajax-modal", "btn-primary")

class ShellinaboxAction(tables.LinkAction):
    name = "shellinabox"
    verbose_name = _("Shell")
    url = settings.SHELL_IN_A_BOX_URL
    classes = ("ajax-modal","btn-primary","btn-shellinabox")


class ListServerTableBase(tables.DataTable):
    STATUS_CHOICES = (
        ("active", True),
        ("available", True),
        ("Active", True),
        ("Stopped", True),
    )

    server_id = tables.Column("id", verbose_name=_("ID"), classes=("server_id",))
    name = tables.Column("name", verbose_name=_("Name"))
    primary_public_ip = tables.Column("primary_public_ip", verbose_name=_("Management Address"))
    secondary_public_ip = tables.Column("secondary_public_ip", verbose_name=_("Public Address"))
    cluster_ip = tables.Column("cluster_ip", verbose_name=_("Cluster Address"))
    ceph_ver = tables.Column("ceph_ver", verbose_name=_("Ceph Version"))
    osds = tables.Column("osds", verbose_name=_("OSDs (Data Drives)"))
    is_monitor = tables.Column("is_monitor", classes=("monitor_tag",), verbose_name=_("Monitor"))
    zone = tables.Column("zone", classes=("zone",), verbose_name=_("Zone"))
    status = tables.Column("status", status=True,
                            status_choices=STATUS_CHOICES,
                            display_choices=STATUS_DISPLAY_CHOICES,
                            verbose_name=_("Status"))

#    createdBy = tables.Column("createdBy", verbose_name=_("Created By"))
#    cluster = tables.Column("clusterName", verbose_name=_("Cluster"))

    class Meta:
        name = "server_list_base"
        verbose_name = _("Cluster Server List")
        table_actions = (AddServersAction, RemoveServersAction, 
                AddMonitorsAction, RemoveMonitorsAction)
        status_columns = ['status']
        row_class = UpdateRow

    def get_object_id(self, datum):
        if hasattr(datum, "id"):
            return datum.id
        else:
            return datum["id"]

    def get_object_display(self, datum):
        if hasattr(datum, "name"):
            return datum.id
        else:
            return datum["name"]

class ListServerTable(ListServerTableBase):
    STATUS_CHOICES = (
        ("active", True),
        ("available", True),
        ("Active", True),
        ("Stopped", True),
    )

    server_id = tables.Column(
                    "id",
                    verbose_name=_("ID"),
                    classes=("server_id",)
                )
    name = tables.Column(
                    "name",
                    verbose_name=_("Name"),
                    classes=("name",)
                )
    primary_public_ip = tables.Column(
                    "primary_public_ip",
                    verbose_name=_("Management Address")
                    ,classes=("primary_public_ip",)
                )
    secondary_public_ip = tables.Column(
                    "secondary_public_ip",
                    verbose_name=_("Public Address"),
                    classes=("secondary_public_ip",)
                )
    cluster_ip = tables.Column(
                    "cluster_ip",
                    verbose_name=_("Cluster Address"),
                    classes=("cluster_ip",)
                )
    ceph_ver = tables.Column(
                    "ceph_ver",
                    verbose_name=_("Ceph Version"),
                    classes=("ceph_ver",)
                )
    osds = tables.Column(
                    "osds",
                    verbose_name=_("OSDs (Data Drives)"),
                    classes=("osds",)
                )
    is_monitor = tables.Column(
                    "is_monitor",
                    verbose_name=_("Monitor"),
                    classes=("monitor_tag",)
                )
    zone = tables.Column(
                    "zone",
                    verbose_name=_("Zone"),
                    classes=("zone",)
                )
    status = tables.Column(
                    "status",
                    status=True,
                    status_choices=STATUS_CHOICES,
                    display_choices=STATUS_DISPLAY_CHOICES,
                    verbose_name=_("Status"),
                    classes=("status",)
                )
    class Meta:
        name = "server_list"
        verbose_name = _("Server List")
        table_actions = (AddServersAction, RemoveServersAction,
                AddMonitorsAction, RemoveMonitorsAction, StartServersAction, StopServersAction)
        #status_columns = ['status']
        #row_class = UpdateRow
        multi_select = False
        #row_actions = (ResetStatus,)

def empty_value_maker(type, name, value, attrs=None):
    def _empty_value_caller(datum):
        if type == "text":
            widget = forms.TextInput()
        elif type == "choice":
            widget = forms.ChoiceField().widget
        elif type == "checkbox":
            widget = forms.CheckboxInput()
        data = dict(name=name, value=value)
        if name in datum.keys():
            data.update(datum[name])
        if attrs:
            data.update(dict(attrs=attrs))
        data = widget.render(**data)
        return data
    return _empty_value_caller

class AddServerTable(tables.DataTable):

    server_id = tables.Column("id", verbose_name=_("ID"), classes=("server_id",))
    name = tables.Column("name", verbose_name=_("Name"))
    primary_public_ip = tables.Column("primary_public_ip", verbose_name=_("Management Address"))
    secondary_public_ip = tables.Column("secondary_public_ip",
        verbose_name=_("Public Address"))
    cluster_ip = tables.Column("cluster_ip", verbose_name=_("Cluster Address"))
    osds = tables.Column("osds", verbose_name=_("OSDs (Data Drives)"))
    is_monitor = tables.Column("is_monitor", verbose_name=_("Monitor"),
        classes=('monitor',), empty_value=empty_value_maker("checkbox","is_monitor",""))
    server_status = tables.Column("status", verbose_name=_("Server Status"), classes=('server_status',))

    class Meta:
        multi_select = True
        name = "tServers"
        verbose_name = _("Add Servers")
        

    def get_object_id(self, datum):
        if hasattr(datum, "id"):
            return datum.id
        else:
            return datum["id"]

    def get_object_display(self, datum):
        if hasattr(datum, "name"):
            return datum.id
        else:
            return datum["name"]

class RemoveServerTable(tables.DataTable):

    server_id = tables.Column("id", verbose_name=_("ID"), classes=("server_id",))
    name = tables.Column("name", classes=("server_name",), verbose_name=_("Name"))
    primary_public_ip = tables.Column("primary_public_ip", verbose_name=_("Management Address"))
    secondary_public_ip = tables.Column("secondary_public_ip",verbose_name=_("Public Address"))
    cluster_ip = tables.Column("cluster_ip", verbose_name=_("Cluster Address"))
    zone = tables.Column("zone", verbose_name=_("Zone"),classes=('zone',), empty_value=empty_value_maker("choice","zone_list","",{"style":"width:80px"}))
    osds = tables.Column("osds", verbose_name=_("OSDs (Data Drives)"))
    is_monitor = tables.Column("is_monitor", classes=("monitor_tag",), verbose_name=_("Monitor"))
    remove_monitor = tables.Column("remove_monitor", verbose_name=_("Monitor"),classes=('remove_monitor',), empty_value=empty_value_maker("checkbox","remove_monitor", True),hidden=True)
    remove_storage = tables.Column("remove_storage", verbose_name=_("Storage"), classes=('remove_storage',),empty_value=empty_value_maker("checkbox","remove_storage",True), hidden=True)
    server_status = tables.Column("status", verbose_name=_("Server Status"), classes=('server_status',))

    class Meta:
        multi_select = True
        name = "tServers"
        verbose_name = _("Remove Servers")

    def get_object_id(self, datum):
        if hasattr(datum, "id"):
            return datum.id
        else:
            return datum["id"]

    def get_object_display(self, datum):
        if hasattr(datum, "name"):
            return datum.id
        else:
            return datum["name"]

class AddServerTable2(AddServerTable):
    is_storage = tables.Column("is_storage", verbose_name=_("Storage"), classes=('storage',),
        empty_value=empty_value_maker("checkbox","is_storage",""))

    class Meta:
        name = "serversaction"
        verbose_name = _("Servers")
        multi_select = True

class AddMonitorTable(ListServerTableBase):
    monitor = tables.Column("is_monitor", verbose_name=_("isMonitor"), hidden=True,
        classes=('monitor',), empty_value=empty_value_maker("checkbox","", 1))
    class Meta:
        name = "tServers"
        verbose_name = _("Add Monitors")
        multi_select = True

class RemoveMonitorTable(ListServerTableBase):
    remove_monitor = tables.Column("remove_monitor", verbose_name=_("Monitor"),
        classes=('remove_monitor',), empty_value=empty_value_maker("checkbox","remove_monitor", True),
        hidden=True)
    remove_storage = tables.Column("remove_storage", verbose_name=_("Storage"), classes=('remove_storage',),
        empty_value=empty_value_maker("checkbox","remove_storage",False), hidden=True)

    class Meta:
        name = "tServers"
        verbose_name = _("Remove Monitors")
        multi_select = True

class StartServerTable(ListServerTableBase):

    class Meta:
        name = "tServers"
        verbose_name = _("Start Servers")
        multi_select = True

class StopServerTable(ListServerTableBase):

    class Meta:
        name = "tServers"
        verbose_name = _("Stop Servers")
        multi_select = True



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import messages
from horizon import tables

from vsm_dashboard.api import vsm as vsmapi

LOG = logging.getLogger(__name__)


class PresentPoolAction(tables.BatchAction):
    name = "presentpools"
    action_present = _("Add Pool to OpenStack")
    action_past = _("Scheduled Present Pools")
    data_type_singular = ("Pool")
    data_type_plural = ("")
    classes = ("btn-presentpools",)

    def allowed(self, request, datum):
        #LOG.error("CEPH_LOG PRESENTPOOL: ALLOW <")
        LOG.info("CEPH_LOG PRESENTPOOL: datum %s" % datum)
        if datum:
            for data in self.table.data:
                if not (data['status'] in ("running", "whatever")):
                    raise ValueError("Some Pools' status is not correct!")

            appnodes = vsmapi.appnode_list(request)
            if len(appnodes) < 1:
                raise ValueError("No Openstack Node!!")

            for appnode in appnodes:
                if appnode.ssh_status != "reachable":
                    messages.error(request, "Can't SSH to AppNode %s" % appnode.ip)
                    raise Exception("abc")

            if datum['status'] not in ("running", "whatever"):
                raise ValueError("Pool %s status is not correct!" % datum['name'])

            pool_usages = vsmapi.pool_usages(request)
            if datum['id'] in [str(p.pool_id) for p in pool_usages]:
                raise ValueError("Pool %s already Connected to Openstack" % datum['name'])

        #LOG.error("CEPH_LOG PRESENTPOOL: ALLOW >")
        return True

    def action(self, request, obj_id):
        LOG.info("CEPH_LOG PRESENTPOOL: ACTION obj_id:%s"%obj_id)
        #LOG.error(obj_id)
        data = self.table.get_object_by_id(obj_id)
        LOG.info("CEPH_LOG PRESENTPOOL: ACTION data:%s"%data)
        #LOG.error(data)
        #LOG.error("CEPH_LOG PRESENTPOOL: ACTION >")
        vsmapi.present_pool(request, [obj_id,])
        messages.success(request, "Present Pool %s Success" % data['name'])

class PresentPoolAction(tables.LinkAction):
    name = "present pools"
    verbose_name = _("Present Pools")
    url = "horizon:vsm:rbdpools:presentpoolsview"
    classes = ("ajax-modal", "btn-primary")

    def allowed(self, request, datum):
        #LOG.error("CEPH_LOG PRESENTPOOL: ALLOW <")
        LOG.info("CEPH_LOG PRESENTPOOL: datum %s" % datum)
        if datum:
            for data in self.table.data:
                if not (data['status'] in ("running", "whatever")):
                    raise ValueError("Some Pools' status is not correct!")

            appnodes = vsmapi.appnode_list(request)
            if len(appnodes) < 1:
                raise ValueError("No Openstack Node!!")

            for appnode in appnodes:
                if appnode.ssh_status != "reachable":
                    messages.error(request, "Can't SSH to AppNode %s" % appnode.ip)
                    raise Exception("abc")

            if datum['status'] not in ("running", "whatever"):
                raise ValueError("Pool %s status is not correct!" % datum['name'])

            pool_usages = vsmapi.pool_usages(request)
            if datum['id'] in [str(p.pool_id) for p in pool_usages]:
                raise ValueError("Pool %s already Connected to Openstack" % datum['name'])

        #LOG.error("CEPH_LOG PRESENTPOOL: ALLOW >")
        return True

class ListPoolTable(tables.DataTable):

    id = tables.Column("id", verbose_name=_("ID"))
    name = tables.Column("name", verbose_name=_("Name"))
    storageType = tables.Column("storageGroup", verbose_name=_("Storage Group"))
    pgNum = tables.Column("pgNum", verbose_name=_("Placement Group Count"))
    size = tables.Column("size", verbose_name=_("Size"))
    status = tables.Column("status", verbose_name=_("Status"))
    createdBy = tables.Column("createdBy", verbose_name=_("Created By"))
    tag = tables.Column("tag", verbose_name=_("Tag"))
    attach_status = tables.Column("attach_status", verbose_name=_("Attach Status"))
#    cluster = tables.Column("clusterName", verbose_name=_("Cluster"))

    class Meta:
        name = "tpools"
        verbose_name = _("Manage Openstack RBD Pools")
        table_actions = (PresentPoolAction, )
        #row_actions = (PresentPoolAction,)
        multi_select = False

    def get_object_id(self, datum):
        if hasattr(datum, "id"):
            return datum.id
        else:
            return datum["id"]

    def get_object_display(self, datum):
        if hasattr(datum, "name"):
            return datum.id
        else:
            return datum["name"]

class ListPresentPoolTable(tables.DataTable):

    id = tables.Column("id", verbose_name=_("ID"), classes=("pool_id",))
    name = tables.Column("name", verbose_name=_("Name"))
    storageType = tables.Column("storageGroup", verbose_name=_("Storage Group"))
    pgNum = tables.Column("pgNum", verbose_name=_("Placement Group Count"))
    size = tables.Column("size", verbose_name=_("Replication Factor"))
    openstack_region = tables.Column("openstack_region",
                                     verbose_name=_("OpenStack/Region"),
                                     classes=("openstack_region",))
    cinder_volume_host = tables.Column("cinder_volume_host",
                                       verbose_name=_("Cinder Volume Host"),
                                       classes=("zone",))
    as_glance_store_pool = tables.Column("as_glance_store_pool",
                                         verbose_name=_("As Glance Store Pool"),
                                         classes=("glance",))
    status = tables.Column("status", verbose_name=_("Status"))
    createdBy = tables.Column("createdBy", verbose_name=_("Created By"))
    tag = tables.Column("tag", verbose_name=_("Tag"))
    attach_status = tables.Column("attach_status", verbose_name=_("Attach Status"))

    class Meta:
        name = "tPools"
        verbose_name = _("Present RBD Pools")
        #row_actions = (PresentPoolAction,)
        multi_select = True

    def get_object_id(self, datum):
        if hasattr(datum, "id"):
            return datum.id
        else:
            return datum["id"]

    def get_object_display(self, datum):
        if hasattr(datum, "name"):
            return datum.id
        else:
            return datum["name"]



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import logging
import os
from django.utils.translation import ugettext_lazy as _
from django.core.urlresolvers import reverse_lazy

from horizon import exceptions
from horizon import tables
from horizon import forms
from horizon import views

from vsm_dashboard.api import vsm as vsmapi
from .tables import ListPGStatusTable
from django.http import HttpResponse

import json
LOG = logging.getLogger(__name__)

from django.views.generic import TemplateView

class ModalSummaryMixin(object):

   def get_context_data(self, **kwargs):
        context = super(ModalSummaryMixin, self).get_context_data(**kwargs)
        return context

class IndexView(ModalSummaryMixin, tables.DataTableView):
    table_class = ListPGStatusTable
    template_name = 'vsm/pg-status/index.html'

    def get_data(self):
        default_limit = 100;
        default_sort_dir = "asc";
        default_sort_keys = ['pgid']
        marker = self.request.GET.get('marker', "")

        _pg_status= []
        #_pgs= vsmapi.get_pg_list(self.request,)
        try:
            _pg_status = vsmapi.placement_group_status(self.request, paginate_opts={
                "limit": default_limit,
                "sort_dir": default_sort_dir,
                "marker":   marker,
            })
            if _pg_status:
                logging.debug("resp body in view: %s" % _pg_status)
        except:
            exceptions.handle(self.request,
                              _('Unable to retrieve sever list. '))

        pg_status = []
        for _pg in _pg_status:
            pg = {"id": _pg.id,
                        "pg_id": _pg.pg_id,
                        "state": _pg.state,
                        "up": _pg.up,
                        "acting": _pg.acting,
                        }

            pg_status.append(pg)
        return pg_status

class SummaryView(ModalSummaryMixin, TemplateView):
    template_name = 'vsm/pg-status/index.html'




# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from datetime import datetime
import json
import logging

from horizon.utils import functions as utils

from django.http import HttpResponse
from django import shortcuts
from django.views.generic import TemplateView

from vsm_dashboard.api import vsm as vsmapi

LOG = logging.getLogger(__name__)


class IndexView(TemplateView):

    template_name = 'vsm/settings/index.html'

    def get_context_data(self, **kwargs):
        context = super(IndexView, self).get_context_data(**kwargs)
        settings = vsmapi.get_settings(self.request)
        for setting in settings:
            setting.verbose_name = setting.name.upper()
        pagination_value = utils.get_page_size(self.request)
        pagination_setting = {"name": "pagination",
                              "verbose_name": "PAGINATION",
                              "value": pagination_value}
        setting_name_tuple = ("STORAGE_GROUP_NEAR_FULL_THRESHOLD",
                              "STORAGE_GROUP_FULL_THRESHOLD",
                              "DISK_NEAR_FULL_THRESHOLD",
                              "DISK_FULL_THRESHOLD",
                              "CPU_DIAMOND_COLLECT_INTERVAL",
                              "CEPH_DIAMOND_COLLECT_INTERVAL",
                              "KEEP_PERFORMANCE_DATA_DAYS")
        context['settings'] = [x for x in settings
                               if x.verbose_name in setting_name_tuple]
        context['settings'].append(pagination_setting)
        return context

def _one_year():
    now = datetime.utcnow()
    return datetime(now.year + 1, now.month, now.day, now.hour,
                    now.minute, now.second, now.microsecond, now.tzinfo)

def SettingsAction(request, action):
    data = json.loads(request.body)
    # TODO add cluster_id in data
    if not len(data):
        status = "error"
        msg = "No server selected"
    else:
        if action == "update":
            key_name = data['keyName']
            if key_name == 'pagination':
                response = shortcuts.redirect(request.build_absolute_uri())
                request.session['horizon_pagesize'] = data['keyValue']
                response.set_cookie('horizon_pagesize', data['keyValue'],
                                    expires=_one_year())
                status = "success"
                msg = "Update Success"
                resp = dict(message=msg, status=status, data="")
                resp = json.dumps(resp)
                return HttpResponse(resp)
            #vsmapi.add_servers(request, data)
            try:
                setting_value = int(data['keyValue'])
                if 0 < setting_value < 21600 or setting_value==0:
                    vsmapi.update_setting(request, data['keyName'], data['keyValue'])
                    status = "success"
                    msg = "Update Success"
                else:
                    status = "failed"
                    msg = "Update Failed"
            except:
                status = 'failed'
                msg = "Update Failed"
        else:
            LOG.error("error in server action %s" % data)
            status = "error"
            msg = "Invalid params"

    resp = dict(message=msg, status=status, data="")
    resp = json.dumps(resp)
    return HttpResponse(resp)




# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import logging
from django.template.defaultfilters import filesizeformat
from django.utils.translation import ugettext_lazy as _
from django.utils.datastructures import SortedDict
from django import forms

from django.utils.safestring import mark_safe
#from vsm_dashboard.dashboards.admin.instances.tables import \
#        AdminUpdateRow

from horizon import tables
from horizon.utils import html
from horizon import exceptions
from vsm_dashboard.api import vsm as vsmapi

from .utils import checkbox_transform

STRING_SEPARATOR = "__"
LOG = logging.getLogger(__name__)

class CreateStorageGroupAction(tables.LinkAction):
    name = "create storage group"
    verbose_name = _("Add Storage Group")
    url = "horizon:vsm:storage-group-management:create"
    classes = ("ajax-modal", "btn-primary")

class ListStorageGroupTable(tables.DataTable):

    storage_group_id = tables.Column("id", verbose_name=_("ID"), classes=("storage_group_list",))

    name = tables.Column("name", verbose_name=_("Name"))
    storage_class = tables.Column("storage_class", verbose_name=_("Storage Class"))
    friendly_name = tables.Column("friendly_name", verbose_name=_("Friendly Name"))

    class Meta:
        name = "storage_group_list"
        verbose_name = _("Storage Group List")
        table_actions = (CreateStorageGroupAction, )
        multi_select = False

    def get_object_id(self, datum):
        if hasattr(datum, "id"):
            return datum.id
        else:
            return datum["id"]

    def get_object_display(self, datum):
        if hasattr(datum, "name"):
            return datum.id
        else:
            return datum["name"]




# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

import datetime

def get_time_delta(dt):
    try:

        timedelta = datetime.datetime.now() - datetime.datetime.strptime(dt,"%Y-%m-%d %H:%M:%S")
        secs = timedelta.days * 3600 * 24 + timedelta.seconds
        ab = 1 if secs > 0 else -1
        days = abs(secs) / (3600 * 24) * ab
        hours = (abs(secs) - abs(days) * 3600 * 24) / 3600 * ab

        if (hours >= 1) or (days >= 1):
            return str(days) + "days, " + str(hours) + " hours ago"
        minutes = secs / 60
        if minutes >= 1:
            return str(minutes) + " minutes ago"
        return str(secs) + " seconds ago"
    except:
        return dt

def get_time_delta2(dt):
    try:
        timedelta = datetime.datetime.now() - datetime.datetime.strptime(dt,"%Y-%m-%d %H:%M:%S")
        secs = timedelta.days * 3600 * 24 + timedelta.seconds
        ab = 1 if secs > 0 else -1
        days = abs(secs) / (3600 * 24) * ab
        hours = (abs(secs) - abs(days) * 3600 * 24) / 3600 * ab
        if (hours >= 1) or (days >= 1):
            return str(days) + "days, " + str(hours) + " hours"
        minutes = secs / 60
        if minutes >= 1:
            return str(minutes) + " minutes"
        return str(secs) + " seconds"
    except:
        return dt

def get_time_delta3(secs):
    try:
        secs = int(float(secs))
        ab = 1 if secs > 0 else -1
        days = abs(secs) / (3600 * 24) * ab
        hours = (abs(secs) - abs(days) * 3600 * 24) / 3600 * ab
        if (hours >= 1) or (days >= 1):
            return str(days) + "days, " + str(hours) + " hours"
        minutes = secs / 60
        if minutes >= 1:
            return str(minutes) + " minutes"
        return str(secs) + " seconds"
    except:
        return secs



# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

from django.core import validators
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _

from horizon import exceptions
from horizon import forms
from horizon import messages
from horizon.utils.validators import validate_port_range
import logging

from vsm_dashboard.api import vsm as vsm_api

LOG = logging.getLogger(__name__)

class ImportCluster(forms.SelfHandlingForm):
    failure_url = 'horizon:vsm:cluster-import:index'
    monitor_host = forms.ChoiceField(label=_("Monitor Host"),
                                    required=True)
    monitor_keyring = forms.CharField(label=_("Monitor Keyring"),
                                    max_length=255,
                                    min_length=1,
                                    required=True)
    cluster_conf = forms.CharField(label=_("Cluster Conf"),
                                    max_length=255,
                                    min_length=1,
                                    required=True)
    def __init__(self, request, *args, **kwargs):
        super(ImportCluster, self).__init__(request, *args, **kwargs)
        monitor_list = []
        try:
            #get the serverlist
            _servers = vsm_api.get_server_list(self.request,)
            for _server in _servers:
                if "monitor" in _server.type:
                    monitor_list.append((_server.id,_server.host))
        except:
            msg = _('Failed to get server_list.')
            redirect = reverse(self.failure_url)
            exceptions.handle(request, msg, redirect=redirect)
            return False
        self.fields["monitor_host"].choices = monitor_list

    def handle(self,request,data):
        pass


# Copyright 2012 Nebula, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from vsm_dashboard.api import swift
from .utils import TestDataContainer

def data(TEST):
    TEST.containers = TestDataContainer()
    TEST.objects = TestDataContainer()

    container_1 = swift.Container(dict(name=u"container_one\u6346"))
    container_2 = swift.Container(dict(name=u"container_two\u6346"))
    TEST.containers.add(container_1, container_2)

    object_dict = {"name": u"test_object\u6346",
                   "content_type": u"text/plain",
                   "bytes": 128,
                   "last_modified": None,
                   "hash": u"object_hash"}
    obj_dicts = [object_dict]
    obj_data = "Fake Data"

    for obj_dict in obj_dicts:
        swift_object = swift.StorageObject(obj_dict,
                                           container_1.name,
                                           data=obj_data)
        TEST.objects.add(swift_object)




# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

from django.core import validators
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _

from horizon import exceptions
from horizon import forms
from horizon import messages
from horizon.utils.validators import validate_port_range
# from horizon.utils import fields
import logging

from vsm_dashboard.api import vsm as vsm_api
from vsm_dashboard.utils.validators import validate_storage_group_name

LOG = logging.getLogger(__name__)

class CreateStorageGroupForm(forms.SelfHandlingForm):

    failure_url = 'horizon:vsm:storage-group-management:index'
    name = forms.CharField(label=_("Storage Group name"),
                            max_length=255,
                            min_length=1,
                            error_messages={
                            'required': _('This field is required.'),
                            'invalid': _("The string may only contain"
                                         " letters ,numbers, dot and underline")},
                            validators=[validate_storage_group_name])
    friendly_name = forms.CharField(label=_("Storage Group Friendly name"),
                            max_length=255,
                            min_length=1,
                            error_messages={
                            'required': _('This field is required.'),
                            'invalid': _("The string may only contain"
                                         " letters ,numbers, dot and underline")},
                            validators=[validate_storage_group_name])
    storage_class = forms.CharField(label=_("Storage Class"),
                            max_length=24,
                            min_length=1,
                            error_messages={
                            'required': _('This field is required.'),
                            'invalid': _("The string may only contain"
                                         " letters ,numbers, dot and underline")},
                            validators=[validate_storage_group_name])

    def handle(self, request, data):
        # TODO deliver a cluster id in data
        data['cluster_id'] = 1
        #try:
        if True:
            LOG.debug("DEBUG in storage groups, %s" % str(data))
            body = {
                    'storage_group': {
                        'name': data['name'],
                        'friendly_name': data['friendly_name'],
                        'storage_class': data['storage_class'],
                        'cluster_id': data['cluster_id']
                    }
            }
            LOG.debug("DEBUG in handle body %s" % str(body))
            rsp = vsm_api.storage_group_create(request, body=body)
            LOG.debug("DEBUG in storage groups" + str(rsp))

            messages.success(request,
                     _('Successfully created Storage Group: %s')
                     % data['name'])
            return True
        #except:
        #    redirect = reverse("horizon:vsm:storage-group-management:index")
        #    exceptions.handle(request,
        #                      _('Unable to create Storage Group.'),
        #                      redirect=redirect)




# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2012 United States Government as represented by the
# Administrator of the National Aeronautics and Space Administration.
# All Rights Reserved.
#
# Copyright 2012 Openstack, LLC
# Copyright 2012 Nebula, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import logging
import urlparse
from pkg_resources import get_distribution

from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from keystoneclient import service_catalog
from keystoneclient.v2_0 import client as keystone_client
from keystoneclient.v2_0 import tokens

from openstack_auth.backend import KEYSTONE_CLIENT_ATTR

from horizon import exceptions

from vsm_dashboard.api import base

LOG = logging.getLogger(__name__)
DEFAULT_ROLE = None

class Service(base.APIDictWrapper):
    """ Wrapper for a dict based on the service data from keystone. """
    _attrs = ['id', 'type', 'name']

    def __init__(self, service, *args, **kwargs):
        super(Service, self).__init__(service, *args, **kwargs)
        self.url = service['endpoints'][0]['internalURL']
        self.host = urlparse.urlparse(self.url).hostname
        self.region = service['endpoints'][0]['region']
        self.disabled = None

    def __unicode__(self):
        if(self.type == "identity"):
            return _("%(type)s (%(backend)s backend)") \
                     % {"type": self.type,
                        "backend": keystone_backend_name()}
        else:
            return self.type

    def __repr__(self):
        return "<Service: %s>" % unicode(self)

def _get_endpoint_url(request, endpoint_type, catalog=None):
    if getattr(request.user, "service_catalog", None):
        return base.url_for(request,
                            service_type='identity',
                            endpoint_type=endpoint_type)
    return request.session.get('region_endpoint',
                               getattr(settings, 'OPENSTACK_KEYSTONE_URL'))

def keystoneclient(request, admin=False):
    """Returns a client connected to the Keystone backend.

    Several forms of authentication are supported:

        * Username + password -> Unscoped authentication
        * Username + password + tenant id -> Scoped authentication
        * Unscoped token -> Unscoped authentication
        * Unscoped token + tenant id -> Scoped authentication
        * Scoped token -> Scoped authentication

    Available services and data from the backend will vary depending on
    whether the authentication was scoped or unscoped.

    Lazy authentication if an ``endpoint`` parameter is provided.

    Calls requiring the admin endpoint should have ``admin=True`` passed in
    as a keyword argument.

    The client is cached so that subsequent API calls during the same
    request/response cycle don't have to be re-authenticated.
    """
    user = request.user
    if admin:
        if not user.is_superuser:
            raise exceptions.NotAuthorized
        endpoint_type = 'adminURL'
    else:
        endpoint_type = getattr(settings,
                                'OPENSTACK_ENDPOINT_TYPE',
                                'internalURL')

    # Take care of client connection caching/fetching a new client.
    # Admin vs. non-admin clients are cached separately for token matching.
    cache_attr = "_keystoneclient_admin" if admin else KEYSTONE_CLIENT_ATTR
    if hasattr(request, cache_attr) and (not user.token.id
            or getattr(request, cache_attr).auth_token == user.token.id):
        LOG.debug("Using cached client for token: %s" % user.token.id)
        conn = getattr(request, cache_attr)
    else:
        endpoint = _get_endpoint_url(request, endpoint_type)
        insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
        LOG.debug("Creating a new keystoneclient connection to %s." % endpoint)

        # TODO: to be removed in H release
        kcversion = get_distribution("python-keystoneclient").version
        if kcversion >= '0.2.0':
            conn = keystone_client.Client(
                token=user.token.id, endpoint=endpoint,
                original_ip=request.environ.get('REMOTE_ADDR', ''),
                insecure=insecure)
        else:
            conn = keystone_client.Client(
                token=user.token.id, endpoint=endpoint,
                insecure=insecure)
        setattr(request, cache_attr, conn)
    return conn

def tenant_create(request, tenant_name, description, enabled):
    return keystoneclient(request, admin=True).tenants.create(tenant_name,
                                                              description,
                                                              enabled)

def tenant_get(request, tenant_id, admin=False):
    return keystoneclient(request, admin=admin).tenants.get(tenant_id)

def tenant_delete(request, tenant_id):
    keystoneclient(request, admin=True).tenants.delete(tenant_id)

def tenant_list(request, admin=False):
    return keystoneclient(request, admin=admin).tenants.list()

def tenant_update(request, tenant_id, tenant_name, description, enabled):
    return keystoneclient(request, admin=True).tenants.update(tenant_id,
                                                              tenant_name,
                                                              description,
                                                              enabled)

def token_create_scoped(request, tenant, token):
    '''
    Creates a scoped token using the tenant id and unscoped token; retrieves
    the service catalog for the given tenant.
    '''
    if hasattr(request, '_keystone'):
        del request._keystone
    c = keystoneclient(request)
    raw_token = c.tokens.authenticate(tenant_id=tenant,
                                      token=token,
                                      return_raw=True)
    c.service_catalog = service_catalog.ServiceCatalog(raw_token)
    if request.user.is_superuser:
        c.management_url = c.service_catalog.url_for(service_type='identity',
                                                     endpoint_type='adminURL')
    else:
        endpoint_type = getattr(settings,
                                'OPENSTACK_ENDPOINT_TYPE',
                                'internalURL')
        c.management_url = c.service_catalog.url_for(
                service_type='identity', endpoint_type=endpoint_type)
    scoped_token = tokens.Token(tokens.TokenManager, raw_token)
    return scoped_token

def user_list(request, tenant_id=None):
    return keystoneclient(request, admin=True).users.list(tenant_id=tenant_id)

def user_create(request, user_id, email, password, tenant_id, enabled):
    return keystoneclient(request, admin=True).users.create(user_id,
                                                            password,
                                                            email,
                                                            tenant_id,
                                                            enabled)

def user_delete(request, user_id):
    keystoneclient(request, admin=True).users.delete(user_id)

def user_get(request, user_id, admin=True):
    return keystoneclient(request, admin=admin).users.get(user_id)

def user_update(request, user, **data):
    return keystoneclient(request, admin=True).users.update(user, **data)

def user_update_enabled(request, user_id, enabled):
    return keystoneclient(request, admin=True).users.update_enabled(user_id,
                                                                    enabled)

def user_update_password(request, user_id, password, admin=True):
    return keystoneclient(request, admin=admin).users.update_password(user_id,
                                                                      password)

def user_update_tenant(request, user_id, tenant_id, admin=True):
    return keystoneclient(request, admin=admin).users.update_tenant(user_id,
                                                                    tenant_id)

def role_list(request):
    """ Returns a global list of available roles. """
    return keystoneclient(request, admin=True).roles.list()

def roles_for_user(request, user, project):
    return keystoneclient(request, admin=True).roles.roles_for_user(user,
                                                                    project)

def add_tenant_user_role(request, tenant_id, user_id, role_id):
    """ Adds a role for a user on a tenant. """
    return keystoneclient(request, admin=True).roles.add_user_role(user_id,
                                                                   role_id,
                                                                   tenant_id)

def remove_tenant_user_role(request, tenant_id, user_id, role_id):
    """ Removes a given single role for a user from a tenant. """
    client = keystoneclient(request, admin=True)
    client.roles.remove_user_role(user_id, role_id, tenant_id)

def remove_tenant_user(request, tenant_id, user_id):
    """ Removes all roles from a user on a tenant, removing them from it. """
    client = keystoneclient(request, admin=True)
    roles = client.roles.roles_for_user(user_id, tenant_id)
    for role in roles:
        client.roles.remove_user_role(user_id, role.id, tenant_id)

def get_default_role(request):
    """
    Gets the default role object from Keystone and saves it as a global
    since this is configured in settings and should not change from request
    to request. Supports lookup by name or id.
    """
    global DEFAULT_ROLE
    default = getattr(settings, "OPENSTACK_KEYSTONE_DEFAULT_ROLE", None)
    if default and DEFAULT_ROLE is None:
        try:
            roles = keystoneclient(request, admin=True).roles.list()
        except:
            roles = []
            exceptions.handle(request)
        for role in roles:
            if role.id == default or role.name == default:
                DEFAULT_ROLE = role
                break
    return DEFAULT_ROLE

def list_ec2_credentials(request, user_id):
    return keystoneclient(request).ec2.list(user_id)

def create_ec2_credentials(request, user_id, tenant_id):
    return keystoneclient(request).ec2.create(user_id, tenant_id)

def get_user_ec2_credentials(request, user_id, access_token):
    return keystoneclient(request).ec2.get(user_id, access_token)

def keystone_can_edit_user():
    backend_settings = getattr(settings, "OPENSTACK_KEYSTONE_BACKEND", {})
    return backend_settings.get('can_edit_user', True)

def keystone_can_edit_project():
    backend_settings = getattr(settings, "OPENSTACK_KEYSTONE_BACKEND", {})
    return backend_settings.get('can_edit_project', True)

def keystone_backend_name():
    if hasattr(settings, "OPENSTACK_KEYSTONE_BACKEND"):
        return settings.OPENSTACK_KEYSTONE_BACKEND['name']
    else:
        return 'unknown'



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2012 Red Hat, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from vsm_dashboard import api
from vsm_dashboard.test import helpers as test

class CinderApiTests(test.APITestCase):
    def test_volume_list(self):
        search_opts = {'all_tenants': 1}
        volumes = self.volumes.list()
        vsmclient = self.stub_vsmclient()
        vsmclient.volumes = self.mox.CreateMockAnything()
        vsmclient.volumes.list(search_opts=search_opts,).AndReturn(volumes)
        self.mox.ReplayAll()

        # No assertions are necessary. Verification is handled by mox.
        api.vsm.volume_list(self.request, search_opts=search_opts)

    def test_volume_snapshot_list(self):
        volume_snapshots = self.volume_snapshots.list()
        vsmclient = self.stub_vsmclient()
        vsmclient.volume_snapshots = self.mox.CreateMockAnything()
        vsmclient.volume_snapshots.list().AndReturn(volume_snapshots)
        self.mox.ReplayAll()

        api.vsm.volume_snapshot_list(self.request)

    def test_volume_snapshot_list_no_volume_configured(self):
        # remove volume from service catalog
        catalog = self.service_catalog
        for service in catalog:
            if service["type"] == "volume":
                self.service_catalog.remove(service)
        volume_snapshots = self.volume_snapshots.list()

        vsmclient = self.stub_vsmclient()
        vsmclient.volume_snapshots = self.mox.CreateMockAnything()
        vsmclient.volume_snapshots.list().AndReturn(volume_snapshots)
        self.mox.ReplayAll()

        api.vsm.volume_snapshot_list(self.request)



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import logging
import os
from django.utils.translation import ugettext_lazy as _
from django.core.urlresolvers import reverse_lazy

from horizon import exceptions
from horizon import tables
from horizon import forms
from horizon import views

from vsm_dashboard.api import vsm as vsmapi
from .tables import ListStorageGroupTable
from .forms import CreateStorageGroupForm
from django.http import HttpResponse

import json
LOG = logging.getLogger(__name__)

class IndexView(tables.DataTableView):
    table_class = ListStorageGroupTable
    template_name = 'vsm/storage-group-management/index.html'

    def get_data(self):
        _sgs = []
        #_sgs= vsmapi.get_sg_list(self.request,)
        try:
            _sgs = vsmapi.storage_group_status(self.request,)
            if _sgs:
                logging.debug("resp body in view: %s" % _sgs)
            settings = vsmapi.get_setting_dict(self.request)
            sg_near_full_threshold = settings['storage_group_near_full_threshold']
            sg_full_threshold = settings['storage_group_full_threshold']
        except:
            exceptions.handle(self.request,
                              _('Unable to retrieve sever list. '))

        storage_group_status = _sgs
        return storage_group_status

class CreateView(forms.ModalFormView):
    form_class = CreateStorageGroupForm
    template_name = 'vsm/storage-group-management/createstoragegroup.html'
    success_url = reverse_lazy('horizon:vsm:storage-group-management:index')


def create_storage_group(request):
    status = ""
    msg = ""
    body = json.loads(request.body)
    try:
        rsp = vsmapi.storage_group_create(request, body=body)
        status = "OK"
        msg = "Add Cache Tier Successfully!"
    except ex:
        print ex
        status = "Failed"
        msg = "Add Cache Tier Failed!"

    resp = dict(message=msg, status=status)
    resp = json.dumps(resp)
    return HttpResponse(resp)



# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

from django.utils.translation import ugettext_lazy as _

import horizon
from vsm_dashboard.dashboards.vsm import dashboard

class ClusterImport(horizon.Panel):
    name = _("Import Cluster")
    slug = 'cluster-import'

dashboard.VizDash.register(ClusterImport)




# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

from django.conf.urls import patterns, url
from .views import IndexView
from .views import CreateClusterView
from .views import IntegrateClusterView
from .views import ClusterAction
from .views import CheckClusterExist
from .views import update_table

urlpatterns = patterns('',
    url(r'^$', IndexView.as_view(), name='index'),
    url(r'^createclusterview/$', CreateClusterView.as_view(), name='createclusterview'),
    url(r'^integrateclusterview/$', IntegrateClusterView.as_view(), name='integrateclusterview'),
    url(r'^cluster/(?P<action>\w+)$', ClusterAction, name='clusteraction'),
    url(r'^check_cluster_exist/$', CheckClusterExist, name='check_cluster_exist'),
    url(r'^update_table/$', update_table, name='update_table'),
)



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from django.template.defaultfilters import filesizeformat
from django.utils.translation import ugettext_lazy as _

#from vsm_dashboard.dashboards.admin.instances.tables import \
#        AdminUpdateRow

from horizon import tables
from vsm_dashboard.api import vsm

class UpdateRow(tables.Row):
    ajax = True

    def get_data(self, request, volume_id):
        volume = vsm.volume_get(request, volume_id)
        if not volume.display_name:
            volume.display_name = volume_id
        return volume

class CreateStoragePool(tables.LinkAction):
    name = "create pool"
    verbose_name = _("Create Replicated Pool")
    url = "horizon:vsm:poolsmanagement:create"
    classes = ("ajax-modal", "btn-primary")

class CreateErasureCodedPool(tables.LinkAction):
    name = "create erasure coded pool"
    verbose_name = _("Create EC Pool")
    url = "horizon:vsm:poolsmanagement:create_ec_pool"
    classes = ("ajax-modal", "btn-primary")

class AddCacheTier(tables.LinkAction):
    name = "add cache tier"
    verbose_name = _("Add Cache Tier")
    url = "horizon:vsm:poolsmanagement:add_cache_tier"
    classes = ("ajax-modal", "btn-primary")

class RemoveCacheTier(tables.LinkAction):
    name = "remove cache tier"
    verbose_name = _("Remove Cache Tier")
    url = "horizon:vsm:poolsmanagement:remove_cache_tier"
    classes = ("ajax-modal", "btn-primary")

class DeleteStoragePool(tables.DeleteAction):
    data_type_singular = _("StoragePool")
    data_type_plural = _("StoragePools")
    action_past = _("Scheduled deletion of")

    def delete(self, request, obj_id):
        obj = self.table.get_object_by_id(obj_id)
        name = self.table.get_object_display(obj)
        try:
            vsm.volume_delete(request, obj_id)
        except:
            msg = _('Unable to delete volume "%s". One or more snapshots '
                    'depend on it.')
            exceptions.check_message(["snapshots", "dependent"], msg % name)
            raise

    def allowed(self, request, volume=None):
        if volume:
            return volume.status in DELETABLE_STATES
        return True

class ListPoolTable(tables.DataTable):

    poolId = tables.Column("poolId", verbose_name=_("ID"))
    name = tables.Column("name", verbose_name=_("Name"))
    storageType = tables.Column("storageGroup", verbose_name=_("Storage Group"))
    #replicaStorageType = tables.Column("replica_storage_group", verbose_name=_("Replica Storage Group"))
    pgNum = tables.Column("pgNum", verbose_name=_("Placement Group Count"))
    size = tables.Column("size", verbose_name=_("Size"))
    quota = tables.Column("empty", verbose_name=_("Quota (GB)"), empty_value=lambda x: "-" if x["quota"] in (0, None) else x["quota"])
    cache_tier_status = tables.Column("cache_tier_status", verbose_name=_("Cache Tier Status"))
    erasure_code_status = tables.Column("erasure_code_status", verbose_name=_("Erasure Code Status"))
    status = tables.Column("status", verbose_name=_("Status"))
    createdBy = tables.Column("createdBy", verbose_name=_("Created By"))
    tag = tables.Column("tag", verbose_name=_("Tag"))
#    cluster = tables.Column("clusterName", verbose_name=_("Cluster"))

    class Meta:
        name = "pools"
        verbose_name = _("Storage Pools")
        table_actions = (AddCacheTier, RemoveCacheTier, CreateStoragePool, CreateErasureCodedPool)
        multi_select = False

    def get_object_id(self, datum):
        if hasattr(datum, "id"):
            return datum.id
        else:
            return datum["id"]

    def get_object_display(self, datum):
        if hasattr(datum, "name"):
            return datum.id
        else:
            return datum["name"]




# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

from django.conf.urls import patterns, url
from .views import index
from .views import version,cluster,capacity,OSD,monitor,MDS,storage,IOPS,PG,latency,bandwidth,CPU,perf_enabled
from .views import osd_summary,monitor_summary,mds_summary,objects_summary,performance_summary,pg_summary,capacity_summary

urlpatterns = patterns('',
    url(r'^$', index, name='index'),
    url(r'^version/$', version, name='version'),
    url(r'^cluster/$', cluster, name='cluster'),
    url(r'^capcity/$', capacity, name='capcity'),
    url(r'^osd/$', OSD, name='OSD'),
    url(r'^monitor/$', monitor, name='monitor'),
    url(r'^mds/$', MDS, name='MDS'),
    url(r'^storage/$', storage, name='storage'),
    url(r'^IOPS/$', IOPS, name='IOPS'),
    url(r'^PG/$', PG, name='PG'),
    url(r'^latency/$', latency, name='latency'),
    url(r'^bandwidth/$', bandwidth, name='bandwidth'),
    url(r'^CPU/$', CPU, name='CPU'),
    url(r'^perf_enabled/$', perf_enabled, name='perf_enabled'),

    url(r'^osd_summary/$', osd_summary, name='osd_summary'),
    url(r'^monitor_summary/$', monitor_summary, name='monitor_summary'),
    url(r'^mds_summary/$', mds_summary, name='mds_summary'),
    url(r'^objects_summary/$', objects_summary, name='objects_summary'),
    url(r'^performance_summary/$', performance_summary, name='performance_summary'),
    url(r'^pg_summary/$', pg_summary, name='pg_summary'),
    url(r'^capacity_summary/$', capacity_summary, name='capacity_summary'),
)




# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

from django.conf.urls import patterns, url
from .views import IndexView
from .views import CreateView
from .views import UpdateView
from .views import update_pwd
from .views import create_user
from .views import UserSettingsView
from .views import user_setting

urlpatterns = patterns('',
    url(r'^$', IndexView.as_view(), name='index'),
    url(r'^update/(?P<user_id>[^/]+)/$', UpdateView.as_view(), name='update'),
    url(r'^setting/$', UserSettingsView.as_view(), name='setting'),
    url(r'^create/$', CreateView.as_view(), name='create'),
    url(r'^update_pwd/$', update_pwd, name='update_pwd'),
    url(r'^create_user/$', create_user, name='create_user'),
    url(r'^user_setting/$', user_setting, name='user_setting')
)



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import json
from django.http import HttpResponse
from django.views.generic import TemplateView
from horizon import tables
from vsm_dashboard.api import vsm as vsmapi
from vsm_dashboard.utils import get_time_delta
from .tables import ListOSDStatusTable

class ModalSummaryMixin(object):
    def get_context_data(self, **kwargs):
        context = super(ModalSummaryMixin, self).get_context_data(**kwargs)
        return context

class IndexView(tables.DataTableView):
    table_class = ListOSDStatusTable
    template_name = 'vsm/osd-status/index.html'

    def get_data(self):
        keyword = self.request.GET.get("keyword","")
        pagerIndex = int(self.request.GET.get("pagerIndex",1))
        return get_datasource(pagerIndex,keyword)["osd_list"]

def calculate_paginate(page_index,osd_list_count):
    page_size = 20
    page_count = int(osd_list_count/page_size)
    page_mod = osd_list_count%page_size

    if page_mod > 0:
        page_count = page_count + 1
    pager_size = 10
    pager_count = int(page_count/(pager_size))
    pager_index = int(page_index/(pager_size))
    if page_count%pager_size > 0:
        pager_count = pager_count + 1
    if page_index%pager_size > 0:
        pager_index = pager_index + 1

    data_start_index = (page_index-1)*page_size
    data_end_index = data_start_index+page_size

    paginate = {
        "page_index":page_index,
        "page_count":page_count,
        "pager_index":pager_index,
        "pager_count":pager_count,
        "data_start_index":data_start_index,
        "data_end_index":data_end_index
    }
    return paginate

def get_datasource(page_index,keyword):
    paginate_opts = {
        "limit":10000,
        "marker":0,
        "sort_keys":'id',
        "sort_dir":'asc',
        "osd_name":keyword,
        "server_name":keyword,
        "zone_name":keyword,
        "state":keyword
    }
    #get the datasource
    datasource = vsmapi.osd_status_sort_and_filter(None,paginate_opts)
    #get the paginate
    paginate = calculate_paginate(page_index,len(datasource))

    #organize the data
    osd_data = {"osd_list":[],"paginate":paginate}
    index = 0
    for item in datasource:
        index += 1
        if index <= paginate['data_start_index'] or index > paginate['data_end_index']:
            continue
        capacity_total =  0 if not item.device['total_capacity_kb'] else int(item.device['total_capacity_kb']/1024)
        capacity_used = 0 if not item.device['used_capacity_kb'] else int(item.device['used_capacity_kb']/1024)
        capacity_avail = 0 if not item.device['avail_capacity_kb'] else int(item.device['avail_capacity_kb']/1024)
        capacity_percent_used = 0 if not item.device['total_capacity_kb'] else item.device['used_capacity_kb'] * 100 / item.device['total_capacity_kb']

        osd = {
            "id":item.id,
            "osd_name": item.osd_name,
            "vsm_status": item.operation_status,
            "osd_state": item.state,
            "crush_weight": item.weight,
            "capacity_total":capacity_total,
            "capacity_used":capacity_used,
            "capacity_avail":capacity_avail,
            "capacity_percent_used":capacity_percent_used, 
            "server": item.service['host'],
            "storage_group": item.storage_group['name'],
            "zone": item.zone,
            "updated_at": get_time_delta(item.updated_at),
            "deviceInfo":"",
            "page_index":paginate["page_index"],
            "page_count":paginate["page_count"],
            "pager_index":paginate["pager_index"],
            "pager_count":paginate["pager_count"],
        }

        osd_data["osd_list"].append(osd)
    
    return osd_data














# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import logging
import os
from django.utils.translation import ugettext_lazy as _
from horizon import exceptions
from horizon import tables
from .tables import ListServerTable
from .tables import CreateClusterTable
from django.http import HttpResponse
from vsm_dashboard.api import vsm as vsmapi

import json
LOG = logging.getLogger(__name__)

class ModalEditTableMixin(object):
    def get_template_names(self):
        if self.request.is_ajax():
            if not hasattr(self, "ajax_template_name"):
                # Transform standard template name to ajax name (leading "_")
                bits = list(os.path.split(self.template_name))
                bits[1] = "".join(("_", bits[1]))
                self.ajax_template_name = os.path.join(*bits)
            template = self.ajax_template_name
        else:
            template = self.template_name
        return template

    def get_context_data(self, **kwargs):
        context = super(ModalEditTableMixin, self).get_context_data(**kwargs)
        if self.request.is_ajax():
            context['hide'] = True
        return context

class IndexView(tables.DataTableView):
    table_class = ListServerTable
    template_name = 'vsm/clustermgmt/index.html'

    def get_data(self):
        _servers = []
        #_servers= vsmapi.get_server_list(self.request,)
        try:
            _servers = vsmapi.get_server_list(self.request,)
            _zones = vsmapi.get_zone_list(self.request)
            if _servers:
                logging.debug("resp body in view: %s" % _servers)
        except:
            exceptions.handle(self.request,
                              _('Unable to retrieve sever list. '))

        zones = {}
        for _zone in _zones:
            zones.setdefault(_zone.id, _zone.name)

        servers = []
        for _server in _servers:
            server = {"id": _server.id,
                        "name": _server.host,
                        "primary_public_ip": _server.primary_public_ip,
                        "secondary_public_ip": _server.secondary_public_ip,
                        "cluster_ip": _server.cluster_ip,
                        "zone_id": _server.zone_id,
                        "zone": "",
                        "osds": _server.osds,
                        "type": _server.type,
                        "status": _server.status}

            if "monitor" in _server.type:
                server['is_monitor'] = "yes"
            else:
                server['is_monitor'] = "no"
            if _server.zone_id in zones:
                server['zone'] = zones[_server.zone_id]
                server['ismonitor'] = ''
                server['isstorage'] = ''
            servers.append(server)
        return servers

class CreateClusterView(ModalEditTableMixin, tables.DataTableView):
    table_class = CreateClusterTable
    template_name = 'vsm/flocking/createcluster.html'
    #success_url = reverse_lazy('horizon:vsm:storageservermgmt:index')

    def get_data(self):
        _zones = []
        _servers = []
        #_servers= vsmapi.get_server_list(self.request,)
        try:
            _servers = vsmapi.get_server_list(self.request,)
            _zones = vsmapi.get_zone_list(self.request,)
            logging.debug("resp body in view: %s" % _servers)
        except:
            exceptions.handle(self.request,
                              _('Unable to retrieve sever list. '))

        zones = {}
        for _zone in _zones:
            zones.setdefault(_zone.id, _zone.name)
        zone_list = zones.items()

        servers = []
        for _server in _servers:
            if _server.status != 'available':
                continue

            server = {"id": _server.id,
                        "name": _server.host,
                        "primary_public_ip": _server.primary_public_ip,
                        "secondary_public_ip": _server.secondary_public_ip,
                        "cluster_ip": _server.cluster_ip,
                        "zone_id": _server.zone_id,
                        "osds": _server.osds,
                        "type": _server.type,
                        "status": _server.status}
            if "monitor" in _server.type:
                server['is_monitor'] = {"value": True}
                server['monitor'] = "yes"
            else:
                server['is_monitor'] = {"value": False}
                server['monitor'] = "no"
            if "storage" in _server.type:
                server['is_storage'] = {"value": True}
                server['storage'] = "yes"
            else:
                server['is_storage'] = {"value": False}
                server['storage'] = "no"
            if "mds" in _server.type:
                server['is_mds'] = {"value": True}
                server['mds'] = "yes"
            else:
                server['is_mds'] = {"value": False}
                server['mds'] = "no"
            if "rgw" in _server.type:
                server['is_rgw'] = {"value": True}
                server['rgw'] = "yes"
            else:
                server['is_rgw'] = {"value": False}
                server['rgw'] = "no"
            if _server.zone_id in zones:
                server['zone'] = zones[_server.zone_id]
            server['ismonitor'] = ''
            server['isstorage'] = ''
            servers.append(server)

        return servers

class IntegrateClusterView(ModalEditTableMixin, tables.DataTableView):
    table_class = CreateClusterTable
    template_name = 'vsm/flocking/createcluster.html'
    #success_url = reverse_lazy('horizon:vsm:storageservermgmt:index')

    def get_data(self):
        _zones = []
        _servers = []
        #_servers= vsmapi.get_server_list(self.request,)
        try:
            _servers = vsmapi.get_server_list(self.request,)
            _zones = vsmapi.get_zone_list(self.request,)
            logging.debug("resp body in view: %s" % _servers)
        except:
            exceptions.handle(self.request,
                              _('Unable to retrieve sever list. '))

        zones = {}
        for _zone in _zones:
            zones.setdefault(_zone.id, _zone.name)
        zone_list = zones.items()

        servers = []
        for _server in _servers:
            if _server.status != 'available':
                continue

            server = {"id": _server.id,
                        "name": _server.host,
                        "primary_public_ip": _server.primary_public_ip,
                        "secondary_public_ip": _server.secondary_public_ip,
                        "cluster_ip": _server.cluster_ip,
                        "zone_id": _server.zone_id,
                        "osds": _server.osds,
                        "type": _server.type,
                        "status": _server.status}
            if "monitor" in _server.type:
                server['is_monitor'] = {"value": True}
                server['monitor'] = "yes"
            else:
                server['is_monitor'] = {"value": False}
                server['monitor'] = "no"
            if "storage" in _server.type:
                server['is_storage'] = {"value": True}
                server['storage'] = "yes"
            else:
                server['is_storage'] = {"value": False}
                server['storage'] = "no"
            if _server.zone_id in zones:
                server['zone'] = zones[_server.zone_id]
            servers.append(server)

        return servers

def ClusterAction(request, action):
    data = json.loads(request.body)
    
    if not len(data):
        status = "error"
        msg = "No server selected"
    else:
        if action == "create":
            vsmapi.create_cluster(request, data)
            status = "info"
            msg = "Began to Create Cluster"
        elif action == "integrate":
            vsmapi.integrate_cluster(request, data)
            status = "info"
            msg = "Began to integrate Cluster"
        else:
            status = "info"
            msg = "Began to Create Cluster"

    resp = dict(message=msg, status=status, data="")
    resp = json.dumps(resp)
    return HttpResponse(resp)

def CheckClusterExist(request):
    is_exsit = True
    pool_status = vsmapi.pool_status(request)
    server_list = vsmapi.get_server_list(None)
    status = [server.status for server in server_list]
    if len(pool_status) == 0 and 'Active' not in status:
        is_exsit = False
    resp = json.dumps({"is_exsit":is_exsit})
    return HttpResponse(resp)


def update_table(request):
    try:
        _zones = vsmapi.get_zone_list(request,)
    except Exception, e:
        exceptions.handle(request,_('Unable to retrieve sever list. '))

    #generate the zone list
    zones = {}
    for _zone in _zones:
        zones.setdefault(_zone.id, _zone.name)

    _server_list = vsmapi.get_server_list(request)
    _new_server_list = []
    for _server in _server_list:
        _zone_name = ""
        _is_monitor = "no"
        if _server.zone_id in zones:
            _zone_name = zones[_server.zone_id]
        if "monitor" in _server.type:
            _is_monitor = "yes"
        _new_server = {
            "id": _server.id,
            "name": _server.host,
            "primary_public_ip": _server.primary_public_ip,
            "secondary_public_ip": _server.secondary_public_ip,
            "cluster_ip": _server.cluster_ip,
            "zone_id": _server.zone_id,
            "zone": _zone_name,
            "osds": _server.osds,
            "type": _server.type,
            "status": _server.status,
            "is_monitor": _is_monitor
        }
        _new_server_list.append(_new_server)

    return HttpResponse(json.dumps(_new_server_list))


# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import tables

from vsm_dashboard.api import vsm as vsmapi

LOG = logging.getLogger(__name__)

class AddOpenstackEndpointAction(tables.LinkAction):
    name = "add openstack endpoint"
    verbose_name = _("Add OpenStack Endpoint")
    url = "horizon:vsm:openstackconnect:create"
    classes = ("ajax-modal", "btn-primary")

    def allowed(self, request, datum):
        # return not len(vsmapi.appnode_list(request))
        return True

class DelOpenstackEndpointAction(tables.DeleteAction):
    data_type_singular = ("IP")
    data_type_plural = ("IPs")
    classes = ("btn-delopenstackip",)

    # TODO delete openstack endpoint
    def allowed(self, request, datum):
        return False

    def delete(self, request, obj_id):
        LOG.info("CEPH_LOG DELOPENSTACKIP: DELETE %s" % obj_id)
        vsmapi.del_appnode(request, obj_id)

class EditOpenstackEndpointAction(tables.LinkAction):
    name = "edit openstack endpoint"
    verbose_name = _("Edit")
    url = "horizon:vsm:openstackconnect:update"
    classes = ("ajax-modal", "btn-primary")

    def allowed(self, request, datum):
        return len([x for x in vsmapi.pool_usages(request) if x.attach_status=="success"]) == 0

class ListOpenstackEndpointTable(tables.DataTable):

    id = tables.Column("id", verbose_name=_("ID"), classes=("ip_list",), hidden=True)
    os_tenant_name = tables.Column("os_tenant_name", verbose_name=_("Tenant Name"))
    os_username = tables.Column("os_username", verbose_name=_("UserName"))
    os_password = tables.Column("os_password", verbose_name=_("Password"), hidden=True)
    os_auth_url = tables.Column("os_auth_url", verbose_name=_("Auth Url"))
    os_region_name = tables.Column("os_region_name", verbose_name=_("Region Name"))
    ssh_user = tables.Column("ssh_user", verbose_name=_("SSH User Name"))
    ssh_status = tables.Column("ssh_status", verbose_name=_("Connection Status"))
    log_info = tables.Column("log_info", verbose_name=_("LOG INFO"))

    class Meta:
        name = "openstack_ip_list"
        verbose_name = _("Manage Openstack Access")
        table_actions = (AddOpenstackEndpointAction, DelOpenstackEndpointAction)
        row_actions = (EditOpenstackEndpointAction,)

    def get_object_id(self, datum):
        if hasattr(datum, "id"):
            return datum.id
        else:
            return datum["id"]



# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2014 Intel Corporation, All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from __future__ import division
import logging
import json
from django.views.generic import TemplateView
from django.http import HttpResponse
from vsm_dashboard.api import vsm as vsmapi
from horizon import exceptions

LOG = logging.getLogger(__name__)

class ModalCrushMapMixin(object):

    def get_context_data(self, **kwargs):
        context = super(ModalCrushMapMixin, self).get_context_data(**kwargs)
        context["sg_list"] = get_sg_list()
        return context

class IndexView(ModalCrushMapMixin, TemplateView):
    template_name = 'vsm/crushmap/index.html'


def get_crushmap_series(request):
    body = {'cluster_id':1}
    ret_code,node_list = vsmapi.get_crushmap_tree_data(request,body)
    node_list = node_list['tree_node']
    print 'node_list=======',node_list

    #generate the crushmap nodes
    crushmap_nodes = []
    type_list = []
    for node in node_list:
        is_parent = False
        is_open = False
        font = ""

        #get the type list
        is_type_exist = False
        for type_item in type_list:
            if type_item["id"] == node["type"]:
                is_type_exist = True
                break
        if is_type_exist == False:
            type_list.append({
                "id":node["type"],
                "name":node["type_name"],
            })

        #if parent id is none,it's "root"
        pID_list = node.get("parent_id",["root"])
        print '111===',node
        for pID in pID_list:
            if pID == "root":
                is_parent = True
                is_open = True
                pID = "root"
            item = {
                "id":node["id"],
                "pId":pID,
                "type_id":node["type"],
                "type_name":node["type_name"],
                "name":node["name"],
                "font":"",
                "open":is_open,
                "isParent":is_parent,
            }
            #append the item into crushmap
            crushmap_nodes.append(item)
    #sort the type_list
    type_list.sort(key=lambda x:x["id"])
    resp = dict(message="", status="OK",crushmap=crushmap_nodes,type_list=type_list)
    resp = json.dumps(resp)
    return HttpResponse(resp)

def get_sg_list():
    _sgs = []
    try:
        _sgs = vsmapi.storage_group_status(None,)
        if _sgs:
            logging.debug("resp body in view: %s" % _sgs)
    except:
        exceptions.handle(None,'Unable to retrieve storage group list.')
    return _sgs


def create_storage_group(request):
    body = json.loads(request.body)
    try:
        http_response_code,ret = vsmapi.storage_group_create_with_takes(request, body=body)
        print '---ret====',ret
        if len(ret.get('error_code')) > 0:
            status = "Failed"
            msg = ret.get('error_msg')
        else:
            status = "OK"
            msg = ret.get('info')
    except ex:
        print ex
        status = "Failed"
        msg = "Add Storage Group Failed!Unknown exception!"

    resp = dict(message=msg, status=status)
    resp = json.dumps(resp)
    return HttpResponse(resp)


def update_storage_group(request):
    body = json.loads(request.body)
    try:
        http_response_code,ret = vsmapi.storage_group_update_with_takes(request, body=body)
        print '---ret====',ret
        if len(ret.get('error_code')) > 0:
            status = "Failed"
            msg = ret.get('error_msg')
        else:
            status = "OK"
            msg = ret.get('info')
    except ex:
        print ex
        status = "Failed"
        msg = "Update Stroage Group Failed!Unknown exception!"

    resp = dict(message=msg, status=status)
    resp = json.dumps(resp)
    return HttpResponse(resp)



import logging
from django.utils.translation import ugettext_lazy as _

from horizon import exceptions
from horizon import tables
from horizon import views

from vsm_dashboard.api import vsm as vsmapi
from .tables import ListServerTable
from django.http import HttpResponse

import json
LOG = logging.getLogger(__name__)

class IndexView(tables.DataTableView):
    table_class = ListServerTable
    template_name = 'vsm/cluster-import/index.html'

    def get_data(self):
        _servers = []
        try:
            _servers = vsmapi.get_server_list(self.request,)
            _zones = vsmapi.get_zone_list(self.request)
            if _servers:
                logging.debug("resp body in view: %s" % _servers)
        except:
            exceptions.handle(self.request,
                              _('Unable to retrieve sever list. '))

        zones = {}
        for _zone in _zones:
            zones.setdefault(_zone.id, _zone.name)

        servers = []
        for _server in _servers:
            server = {"id": _server.id,
                        "name": _server.host,
                        "primary_public_ip": _server.primary_public_ip,
                        "secondary_public_ip": _server.secondary_public_ip,
                        "cluster_ip": _server.cluster_ip,
                        "zone_id": _server.zone_id,
                        "zone": "",
                        "osds": _server.osds,
                        "type": _server.type,
                        "status": _server.status}

            if "monitor" in _server.type:
                server['is_monitor'] = "yes"
            else:
                server['is_monitor'] = "no"
            if _server.zone_id in zones:
                server['zone'] = zones[_server.zone_id]
                server['ismonitor'] = ''
                server['isstorage'] = ''
            servers.append(server)
        return servers

class ImportClusterView(views.APIView):
    #form_class = ImportCluster
    template_name = 'vsm/cluster-import/import_cluster.html'

    def get_data(self, request, context, *args, **kwargs):
        context["monitor_host"] = get_monitor_host(request)
        return  context

def get_monitor_host(request):
    monitor_list = []
    try:
        #get the serverlist
        _servers = vsmapi.get_server_list(request,)
        for _server in _servers:
            if "monitor" in _server.type:
                server_item = {
                    "id":_server.id,
                    "host":_server.host
                }
                monitor_list.append(server_item)
    except:
        pass
    return monitor_list


def auto_detect(request):
    status = ""
    msg = ""
    body = json.loads(request.body)
    print body
    data = {}
    try:
        ret = vsmapi.detect_crushmap(request,body=body)
        ret_cephconf = vsmapi.detect_cephconf(request,body=body)
        status = "OK"
        msg = ret[1].get('crushmap')
        data['crushmap'] = ret[1].get('crushmap')
        data['cephconf'] = ret_cephconf[1].get('cephconf')
    except:
        status = "Failed"
        msg = "Auto detect crush map Failed!"

    resp = dict(message=msg, status=status, data=data)
    resp = json.dumps(resp)
    return HttpResponse(resp)

def validate_conf(request):
    status = ""
    msg = ""
    body = json.loads(request.body)
    print body
    try:
        ret = vsmapi.check_pre_existing_cluster(request,body=body)
        if ret[1].get('error'):
            status = "Failed"
            msg = ret[1].get('error')
            crushmap_tree_data = ret[1].get('crushmap_tree_data')
        else:
            status = "OK"
            msg = "Validate Cluster Successfully!"
            crushmap_tree_data = ret[1].get('crushmap_tree_data')
    except:
        status = "Failed"
        msg = "Validate Cluster Failed!"
    if crushmap_tree_data is not None:
        crushmap_tree_data = get_crushmap_series(crushmap_tree_data)
    resp = dict(message=msg, status=status, crushmap=crushmap_tree_data )
    resp = json.dumps(resp)
    return HttpResponse(resp)


def import_cluster(request):
    status = ""
    msg = ""
    body = json.loads(request.body)
    try:
        ret = vsmapi.import_cluster(request,body=body)
        if ret[1].get('error'):
            status = "Failed"
            msg = ret[1].get('error')
        else:
            status = "OK"
            msg = "Import Cluster Successfully!"
    except:
        status = "Failed"
        msg = "Import Cluster Failed!"

    resp = dict(message=msg, status=status)
    print resp
    resp = json.dumps(resp)
    return HttpResponse(resp)


def get_crushmap_series(node_list):

    #generate the crushmap nodes

    crushmap_nodes = []
    for node in node_list:
        is_parent = False
        is_open = False
        font = ""
        pID_list = node.get("parent_id",["root"])
        for pID in pID_list:
            if pID == "root":
                is_parent = True
                is_open = True
                pID = "root"
            item = {
                "id":node["id"],
                "pId":pID,
                "type":node["type"],
                "name":node["name"],
                "font":"",
                "open":is_open,
                "isParent":is_parent,
            }
            #append the item into crushmap
            crushmap_nodes.append(item)
    return crushmap_nodes



# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

import os

from django.utils.translation import ugettext_lazy as _

from horizon.test.settings import *
from horizon.utils.secret_key import generate_or_read_from_file

from vsm_dashboard.exceptions import UNAUTHORIZED, RECOVERABLE, NOT_FOUND

TEST_DIR = os.path.dirname(os.path.abspath(__file__))
ROOT_PATH = os.path.abspath(os.path.join(TEST_DIR, ".."))

SECRET_KEY = generate_or_read_from_file(os.path.join(TEST_DIR,
                                                     '.secret_key_store'))
ROOT_URLCONF = 'vsm_dashboard.urls'
TEMPLATE_DIRS = (
    os.path.join(TEST_DIR, 'templates'),
)

TEMPLATE_CONTEXT_PROCESSORS += (
    'vsm_dashboard.context_processors.openstack',
)

INSTALLED_APPS = (
    'django.contrib.sessions',
    'django.contrib.staticfiles',
    'django.contrib.messages',
    'django.contrib.humanize',
    'django_nose',
    'openstack_auth',
    'compressor',
    'horizon',
    'vsm_dashboard',
    'vsm_dashboard.dashboards.project',
    'vsm_dashboard.dashboards.admin',
    'vsm_dashboard.dashboards.settings',
)

AUTHENTICATION_BACKENDS = ('openstack_auth.backend.KeystoneBackend',)

SITE_BRANDING = 'VSM'

HORIZON_CONFIG = {
    'dashboards': ('project', 'admin', 'settings'),
    'default_dashboard': 'project',
    "password_validator": {
        "regex": '^.{8,18}$',
        "help_text": _("Password must be between 8 and 18 characters.")
    },
    'user_home': None,
    'help_url': "dashboard/vsm",
    'exceptions': {'recoverable': RECOVERABLE,
                   'not_found': NOT_FOUND,
                   'unauthorized': UNAUTHORIZED},
}

# Set to True to allow users to upload images to glance via Horizon server.
# When enabled, a file form field will appear on the create image form.
# See documentation for deployment considerations.
HORIZON_IMAGES_ALLOW_UPLOAD = True

AVAILABLE_REGIONS = [
    ('http://localhost:5000/v2.0', 'local'),
    ('http://remote:5000/v2.0', 'remote'),
]

OPENSTACK_KEYSTONE_URL = "http://localhost:5000/v2.0"
OPENSTACK_KEYSTONE_DEFAULT_ROLE = "Member"

OPENSTACK_KEYSTONE_BACKEND = {
    'name': 'native',
    'can_edit_user': True,
    'can_edit_project': True
}

OPENSTACK_QUANTUM_NETWORK = {
    'enable_lb': True
}

OPENSTACK_HYPERVISOR_FEATURES = {
    'can_set_mount_point': True,

    # NOTE: as of Grizzly this is not yet supported in Nova so enabling this
    # setting will not do anything useful
    'can_encrypt_volumes': False
}

LOGGING['loggers']['vsm_dashboard'] = {
    'handlers': ['test'],
    'propagate': False,
}

NOSE_ARGS = ['--nocapture',
             '--nologcapture',
             '--cover-package=vsm_dashboard',
             '--cover-inclusive',
             '--all-modules']
